# -*- coding: utf-8 -*-
# **********************************************************************
#
# Copyright (c) 2003-2017 ZeroC, Inc. All rights reserved.
#
# This copy of Ice is licensed to you under the terms described in the
# ICE_LICENSE file included in this distribution.
#
# **********************************************************************
#
# Ice version 3.6.4
#
# <auto-generated>
#
# Generated from file `Graphs.ice'
#
# Warning: do not edit this file.
#
# </auto-generated>
#

from sys import version_info as _version_info_
import Ice, IcePy
import omero_cmd_API_ice
import omero_Collections_ice

# Included module omero
_M_omero = Ice.openModule('omero')

# Included module Ice
_M_Ice = Ice.openModule('Ice')

# Included module Glacier2
_M_Glacier2 = Ice.openModule('Glacier2')

# Included module omero.model
_M_omero.model = Ice.openModule('omero.model')

# Included module omero.sys
_M_omero.sys = Ice.openModule('omero.sys')

# Included module omero.api
_M_omero.api = Ice.openModule('omero.api')

# Included module omero.cmd
_M_omero.cmd = Ice.openModule('omero.cmd')

# Start of module omero
__name__ = 'omero'

# Start of module omero.cmd
__name__ = 'omero.cmd'

# Start of module omero.cmd.graphs
_M_omero.cmd.graphs = Ice.openModule('omero.cmd.graphs')
__name__ = 'omero.cmd.graphs'
_M_omero.cmd.graphs.__doc__ = """
Options that modify GraphModify2 request execution.
By default, a user's related ""orphaned"" objects are typically
included in a request's operation. These options override that
behavior, allowing the client to specify whether to always or
never include given kinds of child object regardless of if they
are orphans.
For annotations, each override is limited to specific annotation
namespaces. (If no namespaces are specified, defaults apply
according to the configuration of the graph request factory.)
"""

if 'ChildOption' not in _M_omero.cmd.graphs.__dict__:
    _M_omero.cmd.graphs.ChildOption = Ice.createTempClass()
    class ChildOption(Ice.Object):
        """
        How GraphModify2 requests should deal with kinds of children,
        related to the target objects.
        By default, it is usual for only orphans to be operated on.
        At least one of includeType or excludeType must be used;
        if a type matches both, then it is included.
        No more than one of includeNs and excludeNs may be used.
        Members:
        includeType -- Include in the operation all children of these types.
        excludeType -- Include in the operation no children of these types.
        includeNs -- For annotations, limit the applicability of this option
        to only those in these namespaces.
        excludeNs -- For annotations, limit the applicability of this option
        to only those not in these namespaces.
        """
        def __init__(self, includeType=None, excludeType=None, includeNs=None, excludeNs=None):
            self.includeType = includeType
            self.excludeType = excludeType
            self.includeNs = includeNs
            self.excludeNs = excludeNs

        def ice_ids(self, current=None):
            return ('::Ice::Object', '::omero::cmd::graphs::ChildOption')

        def ice_id(self, current=None):
            return '::omero::cmd::graphs::ChildOption'

        def ice_staticId():
            return '::omero::cmd::graphs::ChildOption'
        ice_staticId = staticmethod(ice_staticId)

        def __str__(self):
            return IcePy.stringify(self, _M_omero.cmd.graphs._t_ChildOption)

        __repr__ = __str__

    _M_omero.cmd.graphs.ChildOptionPrx = Ice.createTempClass()
    class ChildOptionPrx(Ice.ObjectPrx):

        def checkedCast(proxy, facetOrCtx=None, _ctx=None):
            return _M_omero.cmd.graphs.ChildOptionPrx.ice_checkedCast(proxy, '::omero::cmd::graphs::ChildOption', facetOrCtx, _ctx)
        checkedCast = staticmethod(checkedCast)

        def uncheckedCast(proxy, facet=None):
            return _M_omero.cmd.graphs.ChildOptionPrx.ice_uncheckedCast(proxy, facet)
        uncheckedCast = staticmethod(uncheckedCast)

        def ice_staticId():
            return '::omero::cmd::graphs::ChildOption'
        ice_staticId = staticmethod(ice_staticId)

    _M_omero.cmd.graphs._t_ChildOptionPrx = IcePy.defineProxy('::omero::cmd::graphs::ChildOption', ChildOptionPrx)

    _M_omero.cmd.graphs._t_ChildOption = IcePy.defineClass('::omero::cmd::graphs::ChildOption', ChildOption, -1, (), False, False, None, (), (
        ('includeType', (), _M_omero.api._t_StringSet, False, 0),
        ('excludeType', (), _M_omero.api._t_StringSet, False, 0),
        ('includeNs', (), _M_omero.api._t_StringSet, False, 0),
        ('excludeNs', (), _M_omero.api._t_StringSet, False, 0)
    ))
    ChildOption._ice_type = _M_omero.cmd.graphs._t_ChildOption

    _M_omero.cmd.graphs.ChildOption = ChildOption
    del ChildOption

    _M_omero.cmd.graphs.ChildOptionPrx = ChildOptionPrx
    del ChildOptionPrx

if '_t_ChildOptions' not in _M_omero.cmd.graphs.__dict__:
    _M_omero.cmd.graphs._t_ChildOptions = IcePy.defineSequence('::omero::cmd::graphs::ChildOptions', (), _M_omero.cmd.graphs._t_ChildOption)

# End of module omero.cmd.graphs

__name__ = 'omero.cmd'

if 'GraphQuery' not in _M_omero.cmd.__dict__:
    _M_omero.cmd.GraphQuery = Ice.createTempClass()
    class GraphQuery(_M_omero.cmd.Request):
        """
        Base class for new requests for reading the model object graph.
        Members:
        targetObjects -- The model objects upon which to operate.
        Related model objects may also be targeted.
        """
        def __init__(self, targetObjects=None):
            _M_omero.cmd.Request.__init__(self)
            self.targetObjects = targetObjects

        def ice_ids(self, current=None):
            return ('::Ice::Object', '::omero::cmd::GraphQuery', '::omero::cmd::Request')

        def ice_id(self, current=None):
            return '::omero::cmd::GraphQuery'

        def ice_staticId():
            return '::omero::cmd::GraphQuery'
        ice_staticId = staticmethod(ice_staticId)

        def __str__(self):
            return IcePy.stringify(self, _M_omero.cmd._t_GraphQuery)

        __repr__ = __str__

    _M_omero.cmd.GraphQueryPrx = Ice.createTempClass()
    class GraphQueryPrx(_M_omero.cmd.RequestPrx):

        def checkedCast(proxy, facetOrCtx=None, _ctx=None):
            return _M_omero.cmd.GraphQueryPrx.ice_checkedCast(proxy, '::omero::cmd::GraphQuery', facetOrCtx, _ctx)
        checkedCast = staticmethod(checkedCast)

        def uncheckedCast(proxy, facet=None):
            return _M_omero.cmd.GraphQueryPrx.ice_uncheckedCast(proxy, facet)
        uncheckedCast = staticmethod(uncheckedCast)

        def ice_staticId():
            return '::omero::cmd::GraphQuery'
        ice_staticId = staticmethod(ice_staticId)

    _M_omero.cmd._t_GraphQueryPrx = IcePy.defineProxy('::omero::cmd::GraphQuery', GraphQueryPrx)

    _M_omero.cmd._t_GraphQuery = IcePy.defineClass('::omero::cmd::GraphQuery', GraphQuery, -1, (), False, False, _M_omero.cmd._t_Request, (), (('targetObjects', (), _M_omero.api._t_StringLongListMap, False, 0),))
    GraphQuery._ice_type = _M_omero.cmd._t_GraphQuery

    _M_omero.cmd.GraphQuery = GraphQuery
    del GraphQuery

    _M_omero.cmd.GraphQueryPrx = GraphQueryPrx
    del GraphQueryPrx

if 'GraphModify2' not in _M_omero.cmd.__dict__:
    _M_omero.cmd.GraphModify2 = Ice.createTempClass()
    class GraphModify2(_M_omero.cmd.GraphQuery):
        """
        Base class for new requests for modifying the model object graph.
        Members:
        childOptions -- If the request should operate on specific kinds of children.
        Only the first applicable option takes effect.
        dryRun -- If this request should skip the actual model object updates.
        The response is still as if the operation actually occurred,
        indicating what would have been done to which objects.
        """
        def __init__(self, targetObjects=None, childOptions=None, dryRun=False):
            _M_omero.cmd.GraphQuery.__init__(self, targetObjects)
            self.childOptions = childOptions
            self.dryRun = dryRun

        def ice_ids(self, current=None):
            return ('::Ice::Object', '::omero::cmd::GraphModify2', '::omero::cmd::GraphQuery', '::omero::cmd::Request')

        def ice_id(self, current=None):
            return '::omero::cmd::GraphModify2'

        def ice_staticId():
            return '::omero::cmd::GraphModify2'
        ice_staticId = staticmethod(ice_staticId)

        def __str__(self):
            return IcePy.stringify(self, _M_omero.cmd._t_GraphModify2)

        __repr__ = __str__

    _M_omero.cmd.GraphModify2Prx = Ice.createTempClass()
    class GraphModify2Prx(_M_omero.cmd.GraphQueryPrx):

        def checkedCast(proxy, facetOrCtx=None, _ctx=None):
            return _M_omero.cmd.GraphModify2Prx.ice_checkedCast(proxy, '::omero::cmd::GraphModify2', facetOrCtx, _ctx)
        checkedCast = staticmethod(checkedCast)

        def uncheckedCast(proxy, facet=None):
            return _M_omero.cmd.GraphModify2Prx.ice_uncheckedCast(proxy, facet)
        uncheckedCast = staticmethod(uncheckedCast)

        def ice_staticId():
            return '::omero::cmd::GraphModify2'
        ice_staticId = staticmethod(ice_staticId)

    _M_omero.cmd._t_GraphModify2Prx = IcePy.defineProxy('::omero::cmd::GraphModify2', GraphModify2Prx)

    _M_omero.cmd._t_GraphModify2 = IcePy.declareClass('::omero::cmd::GraphModify2')

    _M_omero.cmd._t_GraphModify2 = IcePy.defineClass('::omero::cmd::GraphModify2', GraphModify2, -1, (), False, False, _M_omero.cmd._t_GraphQuery, (), (
        ('childOptions', (), _M_omero.cmd.graphs._t_ChildOptions, False, 0),
        ('dryRun', (), IcePy._t_bool, False, 0)
    ))
    GraphModify2._ice_type = _M_omero.cmd._t_GraphModify2

    _M_omero.cmd.GraphModify2 = GraphModify2
    del GraphModify2

    _M_omero.cmd.GraphModify2Prx = GraphModify2Prx
    del GraphModify2Prx

if 'Chgrp2' not in _M_omero.cmd.__dict__:
    _M_omero.cmd.Chgrp2 = Ice.createTempClass()
    class Chgrp2(_M_omero.cmd.GraphModify2):
        """
        Move model objects into a different experimenter group.
        The user must be either an administrator,
        or the owner of the objects and a member of the target group.
        Members:
        groupId -- The ID of the experimenter group into which to move the model
        objects.
        """
        def __init__(self, targetObjects=None, childOptions=None, dryRun=False, groupId=0):
            _M_omero.cmd.GraphModify2.__init__(self, targetObjects, childOptions, dryRun)
            self.groupId = groupId

        def ice_ids(self, current=None):
            return ('::Ice::Object', '::omero::cmd::Chgrp2', '::omero::cmd::GraphModify2', '::omero::cmd::GraphQuery', '::omero::cmd::Request')

        def ice_id(self, current=None):
            return '::omero::cmd::Chgrp2'

        def ice_staticId():
            return '::omero::cmd::Chgrp2'
        ice_staticId = staticmethod(ice_staticId)

        def __str__(self):
            return IcePy.stringify(self, _M_omero.cmd._t_Chgrp2)

        __repr__ = __str__

    _M_omero.cmd.Chgrp2Prx = Ice.createTempClass()
    class Chgrp2Prx(_M_omero.cmd.GraphModify2Prx):

        def checkedCast(proxy, facetOrCtx=None, _ctx=None):
            return _M_omero.cmd.Chgrp2Prx.ice_checkedCast(proxy, '::omero::cmd::Chgrp2', facetOrCtx, _ctx)
        checkedCast = staticmethod(checkedCast)

        def uncheckedCast(proxy, facet=None):
            return _M_omero.cmd.Chgrp2Prx.ice_uncheckedCast(proxy, facet)
        uncheckedCast = staticmethod(uncheckedCast)

        def ice_staticId():
            return '::omero::cmd::Chgrp2'
        ice_staticId = staticmethod(ice_staticId)

    _M_omero.cmd._t_Chgrp2Prx = IcePy.defineProxy('::omero::cmd::Chgrp2', Chgrp2Prx)

    _M_omero.cmd._t_Chgrp2 = IcePy.declareClass('::omero::cmd::Chgrp2')

    _M_omero.cmd._t_Chgrp2 = IcePy.defineClass('::omero::cmd::Chgrp2', Chgrp2, -1, (), False, False, _M_omero.cmd._t_GraphModify2, (), (('groupId', (), IcePy._t_long, False, 0),))
    Chgrp2._ice_type = _M_omero.cmd._t_Chgrp2

    _M_omero.cmd.Chgrp2 = Chgrp2
    del Chgrp2

    _M_omero.cmd.Chgrp2Prx = Chgrp2Prx
    del Chgrp2Prx

if 'Chgrp2Response' not in _M_omero.cmd.__dict__:
    _M_omero.cmd.Chgrp2Response = Ice.createTempClass()
    class Chgrp2Response(_M_omero.cmd.OK):
        """
        Result of moving model objects into a different experimenter
        group.
        Members:
        includedObjects -- The model objects that were moved.
        deletedObjects -- The model objects that were deleted.
        """
        def __init__(self, includedObjects=None, deletedObjects=None):
            _M_omero.cmd.OK.__init__(self)
            self.includedObjects = includedObjects
            self.deletedObjects = deletedObjects

        def ice_ids(self, current=None):
            return ('::Ice::Object', '::omero::cmd::Chgrp2Response', '::omero::cmd::OK', '::omero::cmd::Response')

        def ice_id(self, current=None):
            return '::omero::cmd::Chgrp2Response'

        def ice_staticId():
            return '::omero::cmd::Chgrp2Response'
        ice_staticId = staticmethod(ice_staticId)

        def __str__(self):
            return IcePy.stringify(self, _M_omero.cmd._t_Chgrp2Response)

        __repr__ = __str__

    _M_omero.cmd.Chgrp2ResponsePrx = Ice.createTempClass()
    class Chgrp2ResponsePrx(_M_omero.cmd.OKPrx):

        def checkedCast(proxy, facetOrCtx=None, _ctx=None):
            return _M_omero.cmd.Chgrp2ResponsePrx.ice_checkedCast(proxy, '::omero::cmd::Chgrp2Response', facetOrCtx, _ctx)
        checkedCast = staticmethod(checkedCast)

        def uncheckedCast(proxy, facet=None):
            return _M_omero.cmd.Chgrp2ResponsePrx.ice_uncheckedCast(proxy, facet)
        uncheckedCast = staticmethod(uncheckedCast)

        def ice_staticId():
            return '::omero::cmd::Chgrp2Response'
        ice_staticId = staticmethod(ice_staticId)

    _M_omero.cmd._t_Chgrp2ResponsePrx = IcePy.defineProxy('::omero::cmd::Chgrp2Response', Chgrp2ResponsePrx)

    _M_omero.cmd._t_Chgrp2Response = IcePy.defineClass('::omero::cmd::Chgrp2Response', Chgrp2Response, -1, (), False, False, _M_omero.cmd._t_OK, (), (
        ('includedObjects', (), _M_omero.api._t_StringLongListMap, False, 0),
        ('deletedObjects', (), _M_omero.api._t_StringLongListMap, False, 0)
    ))
    Chgrp2Response._ice_type = _M_omero.cmd._t_Chgrp2Response

    _M_omero.cmd.Chgrp2Response = Chgrp2Response
    del Chgrp2Response

    _M_omero.cmd.Chgrp2ResponsePrx = Chgrp2ResponsePrx
    del Chgrp2ResponsePrx

if 'Chmod2' not in _M_omero.cmd.__dict__:
    _M_omero.cmd.Chmod2 = Ice.createTempClass()
    class Chmod2(_M_omero.cmd.GraphModify2):
        """
        Change the permissions on model objects.
        The user must be an administrator, the owner of the objects,
        or an owner of the objects' group.
        The only permitted target object type is ExperimenterGroup.
        Members:
        permissions -- The permissions to set on the model objects.
        """
        def __init__(self, targetObjects=None, childOptions=None, dryRun=False, permissions=''):
            _M_omero.cmd.GraphModify2.__init__(self, targetObjects, childOptions, dryRun)
            self.permissions = permissions

        def ice_ids(self, current=None):
            return ('::Ice::Object', '::omero::cmd::Chmod2', '::omero::cmd::GraphModify2', '::omero::cmd::GraphQuery', '::omero::cmd::Request')

        def ice_id(self, current=None):
            return '::omero::cmd::Chmod2'

        def ice_staticId():
            return '::omero::cmd::Chmod2'
        ice_staticId = staticmethod(ice_staticId)

        def __str__(self):
            return IcePy.stringify(self, _M_omero.cmd._t_Chmod2)

        __repr__ = __str__

    _M_omero.cmd.Chmod2Prx = Ice.createTempClass()
    class Chmod2Prx(_M_omero.cmd.GraphModify2Prx):

        def checkedCast(proxy, facetOrCtx=None, _ctx=None):
            return _M_omero.cmd.Chmod2Prx.ice_checkedCast(proxy, '::omero::cmd::Chmod2', facetOrCtx, _ctx)
        checkedCast = staticmethod(checkedCast)

        def uncheckedCast(proxy, facet=None):
            return _M_omero.cmd.Chmod2Prx.ice_uncheckedCast(proxy, facet)
        uncheckedCast = staticmethod(uncheckedCast)

        def ice_staticId():
            return '::omero::cmd::Chmod2'
        ice_staticId = staticmethod(ice_staticId)

    _M_omero.cmd._t_Chmod2Prx = IcePy.defineProxy('::omero::cmd::Chmod2', Chmod2Prx)

    _M_omero.cmd._t_Chmod2 = IcePy.declareClass('::omero::cmd::Chmod2')

    _M_omero.cmd._t_Chmod2 = IcePy.defineClass('::omero::cmd::Chmod2', Chmod2, -1, (), False, False, _M_omero.cmd._t_GraphModify2, (), (('permissions', (), IcePy._t_string, False, 0),))
    Chmod2._ice_type = _M_omero.cmd._t_Chmod2

    _M_omero.cmd.Chmod2 = Chmod2
    del Chmod2

    _M_omero.cmd.Chmod2Prx = Chmod2Prx
    del Chmod2Prx

if 'Chmod2Response' not in _M_omero.cmd.__dict__:
    _M_omero.cmd.Chmod2Response = Ice.createTempClass()
    class Chmod2Response(_M_omero.cmd.OK):
        """
        Result of changing the permissions on model objects.
        Members:
        includedObjects -- The model objects with changed permissions.
        deletedObjects -- The model objects that were deleted.
        """
        def __init__(self, includedObjects=None, deletedObjects=None):
            _M_omero.cmd.OK.__init__(self)
            self.includedObjects = includedObjects
            self.deletedObjects = deletedObjects

        def ice_ids(self, current=None):
            return ('::Ice::Object', '::omero::cmd::Chmod2Response', '::omero::cmd::OK', '::omero::cmd::Response')

        def ice_id(self, current=None):
            return '::omero::cmd::Chmod2Response'

        def ice_staticId():
            return '::omero::cmd::Chmod2Response'
        ice_staticId = staticmethod(ice_staticId)

        def __str__(self):
            return IcePy.stringify(self, _M_omero.cmd._t_Chmod2Response)

        __repr__ = __str__

    _M_omero.cmd.Chmod2ResponsePrx = Ice.createTempClass()
    class Chmod2ResponsePrx(_M_omero.cmd.OKPrx):

        def checkedCast(proxy, facetOrCtx=None, _ctx=None):
            return _M_omero.cmd.Chmod2ResponsePrx.ice_checkedCast(proxy, '::omero::cmd::Chmod2Response', facetOrCtx, _ctx)
        checkedCast = staticmethod(checkedCast)

        def uncheckedCast(proxy, facet=None):
            return _M_omero.cmd.Chmod2ResponsePrx.ice_uncheckedCast(proxy, facet)
        uncheckedCast = staticmethod(uncheckedCast)

        def ice_staticId():
            return '::omero::cmd::Chmod2Response'
        ice_staticId = staticmethod(ice_staticId)

    _M_omero.cmd._t_Chmod2ResponsePrx = IcePy.defineProxy('::omero::cmd::Chmod2Response', Chmod2ResponsePrx)

    _M_omero.cmd._t_Chmod2Response = IcePy.defineClass('::omero::cmd::Chmod2Response', Chmod2Response, -1, (), False, False, _M_omero.cmd._t_OK, (), (
        ('includedObjects', (), _M_omero.api._t_StringLongListMap, False, 0),
        ('deletedObjects', (), _M_omero.api._t_StringLongListMap, False, 0)
    ))
    Chmod2Response._ice_type = _M_omero.cmd._t_Chmod2Response

    _M_omero.cmd.Chmod2Response = Chmod2Response
    del Chmod2Response

    _M_omero.cmd.Chmod2ResponsePrx = Chmod2ResponsePrx
    del Chmod2ResponsePrx

if 'Chown2' not in _M_omero.cmd.__dict__:
    _M_omero.cmd.Chown2 = Ice.createTempClass()
    class Chown2(_M_omero.cmd.GraphModify2):
        """
        Change the ownership of model objects.
        The user must be an administrator, or they
        must be an owner of the objects' group, with
        the target user a member of the objects' group.
        Members:
        userId -- The ID of the experimenter to which to give the model
        objects.
        targetUsers -- The users who should have all their data targeted.
        """
        def __init__(self, targetObjects=None, childOptions=None, dryRun=False, userId=0, targetUsers=None):
            _M_omero.cmd.GraphModify2.__init__(self, targetObjects, childOptions, dryRun)
            self.userId = userId
            self.targetUsers = targetUsers

        def ice_ids(self, current=None):
            return ('::Ice::Object', '::omero::cmd::Chown2', '::omero::cmd::GraphModify2', '::omero::cmd::GraphQuery', '::omero::cmd::Request')

        def ice_id(self, current=None):
            return '::omero::cmd::Chown2'

        def ice_staticId():
            return '::omero::cmd::Chown2'
        ice_staticId = staticmethod(ice_staticId)

        def __str__(self):
            return IcePy.stringify(self, _M_omero.cmd._t_Chown2)

        __repr__ = __str__

    _M_omero.cmd.Chown2Prx = Ice.createTempClass()
    class Chown2Prx(_M_omero.cmd.GraphModify2Prx):

        def checkedCast(proxy, facetOrCtx=None, _ctx=None):
            return _M_omero.cmd.Chown2Prx.ice_checkedCast(proxy, '::omero::cmd::Chown2', facetOrCtx, _ctx)
        checkedCast = staticmethod(checkedCast)

        def uncheckedCast(proxy, facet=None):
            return _M_omero.cmd.Chown2Prx.ice_uncheckedCast(proxy, facet)
        uncheckedCast = staticmethod(uncheckedCast)

        def ice_staticId():
            return '::omero::cmd::Chown2'
        ice_staticId = staticmethod(ice_staticId)

    _M_omero.cmd._t_Chown2Prx = IcePy.defineProxy('::omero::cmd::Chown2', Chown2Prx)

    _M_omero.cmd._t_Chown2 = IcePy.declareClass('::omero::cmd::Chown2')

    _M_omero.cmd._t_Chown2 = IcePy.defineClass('::omero::cmd::Chown2', Chown2, -1, (), False, False, _M_omero.cmd._t_GraphModify2, (), (
        ('userId', (), IcePy._t_long, False, 0),
        ('targetUsers', (), _M_omero.api._t_LongList, False, 0)
    ))
    Chown2._ice_type = _M_omero.cmd._t_Chown2

    _M_omero.cmd.Chown2 = Chown2
    del Chown2

    _M_omero.cmd.Chown2Prx = Chown2Prx
    del Chown2Prx

if 'Chown2Response' not in _M_omero.cmd.__dict__:
    _M_omero.cmd.Chown2Response = Ice.createTempClass()
    class Chown2Response(_M_omero.cmd.OK):
        """
        Result of changing the ownership of model objects.
        Members:
        includedObjects -- The model objects that were given.
        deletedObjects -- The model objects that were deleted.
        """
        def __init__(self, includedObjects=None, deletedObjects=None):
            _M_omero.cmd.OK.__init__(self)
            self.includedObjects = includedObjects
            self.deletedObjects = deletedObjects

        def ice_ids(self, current=None):
            return ('::Ice::Object', '::omero::cmd::Chown2Response', '::omero::cmd::OK', '::omero::cmd::Response')

        def ice_id(self, current=None):
            return '::omero::cmd::Chown2Response'

        def ice_staticId():
            return '::omero::cmd::Chown2Response'
        ice_staticId = staticmethod(ice_staticId)

        def __str__(self):
            return IcePy.stringify(self, _M_omero.cmd._t_Chown2Response)

        __repr__ = __str__

    _M_omero.cmd.Chown2ResponsePrx = Ice.createTempClass()
    class Chown2ResponsePrx(_M_omero.cmd.OKPrx):

        def checkedCast(proxy, facetOrCtx=None, _ctx=None):
            return _M_omero.cmd.Chown2ResponsePrx.ice_checkedCast(proxy, '::omero::cmd::Chown2Response', facetOrCtx, _ctx)
        checkedCast = staticmethod(checkedCast)

        def uncheckedCast(proxy, facet=None):
            return _M_omero.cmd.Chown2ResponsePrx.ice_uncheckedCast(proxy, facet)
        uncheckedCast = staticmethod(uncheckedCast)

        def ice_staticId():
            return '::omero::cmd::Chown2Response'
        ice_staticId = staticmethod(ice_staticId)

    _M_omero.cmd._t_Chown2ResponsePrx = IcePy.defineProxy('::omero::cmd::Chown2Response', Chown2ResponsePrx)

    _M_omero.cmd._t_Chown2Response = IcePy.defineClass('::omero::cmd::Chown2Response', Chown2Response, -1, (), False, False, _M_omero.cmd._t_OK, (), (
        ('includedObjects', (), _M_omero.api._t_StringLongListMap, False, 0),
        ('deletedObjects', (), _M_omero.api._t_StringLongListMap, False, 0)
    ))
    Chown2Response._ice_type = _M_omero.cmd._t_Chown2Response

    _M_omero.cmd.Chown2Response = Chown2Response
    del Chown2Response

    _M_omero.cmd.Chown2ResponsePrx = Chown2ResponsePrx
    del Chown2ResponsePrx

if 'Delete2' not in _M_omero.cmd.__dict__:
    _M_omero.cmd.Delete2 = Ice.createTempClass()
    class Delete2(_M_omero.cmd.GraphModify2):
        """
        Delete model objects.
        Members:
        typesToIgnore -- Ignore in the operation all objects of these types.
        """
        def __init__(self, targetObjects=None, childOptions=None, dryRun=False, typesToIgnore=None):
            _M_omero.cmd.GraphModify2.__init__(self, targetObjects, childOptions, dryRun)
            self.typesToIgnore = typesToIgnore

        def ice_ids(self, current=None):
            return ('::Ice::Object', '::omero::cmd::Delete2', '::omero::cmd::GraphModify2', '::omero::cmd::GraphQuery', '::omero::cmd::Request')

        def ice_id(self, current=None):
            return '::omero::cmd::Delete2'

        def ice_staticId():
            return '::omero::cmd::Delete2'
        ice_staticId = staticmethod(ice_staticId)

        def __str__(self):
            return IcePy.stringify(self, _M_omero.cmd._t_Delete2)

        __repr__ = __str__

    _M_omero.cmd.Delete2Prx = Ice.createTempClass()
    class Delete2Prx(_M_omero.cmd.GraphModify2Prx):

        def checkedCast(proxy, facetOrCtx=None, _ctx=None):
            return _M_omero.cmd.Delete2Prx.ice_checkedCast(proxy, '::omero::cmd::Delete2', facetOrCtx, _ctx)
        checkedCast = staticmethod(checkedCast)

        def uncheckedCast(proxy, facet=None):
            return _M_omero.cmd.Delete2Prx.ice_uncheckedCast(proxy, facet)
        uncheckedCast = staticmethod(uncheckedCast)

        def ice_staticId():
            return '::omero::cmd::Delete2'
        ice_staticId = staticmethod(ice_staticId)

    _M_omero.cmd._t_Delete2Prx = IcePy.defineProxy('::omero::cmd::Delete2', Delete2Prx)

    _M_omero.cmd._t_Delete2 = IcePy.declareClass('::omero::cmd::Delete2')

    _M_omero.cmd._t_Delete2 = IcePy.defineClass('::omero::cmd::Delete2', Delete2, -1, (), False, False, _M_omero.cmd._t_GraphModify2, (), (('typesToIgnore', (), _M_omero.api._t_StringSet, False, 0),))
    Delete2._ice_type = _M_omero.cmd._t_Delete2

    _M_omero.cmd.Delete2 = Delete2
    del Delete2

    _M_omero.cmd.Delete2Prx = Delete2Prx
    del Delete2Prx

if 'Delete2Response' not in _M_omero.cmd.__dict__:
    _M_omero.cmd.Delete2Response = Ice.createTempClass()
    class Delete2Response(_M_omero.cmd.OK):
        """
        Result of deleting model objects.
        Members:
        deletedObjects -- The model objects that were deleted.
        """
        def __init__(self, deletedObjects=None):
            _M_omero.cmd.OK.__init__(self)
            self.deletedObjects = deletedObjects

        def ice_ids(self, current=None):
            return ('::Ice::Object', '::omero::cmd::Delete2Response', '::omero::cmd::OK', '::omero::cmd::Response')

        def ice_id(self, current=None):
            return '::omero::cmd::Delete2Response'

        def ice_staticId():
            return '::omero::cmd::Delete2Response'
        ice_staticId = staticmethod(ice_staticId)

        def __str__(self):
            return IcePy.stringify(self, _M_omero.cmd._t_Delete2Response)

        __repr__ = __str__

    _M_omero.cmd.Delete2ResponsePrx = Ice.createTempClass()
    class Delete2ResponsePrx(_M_omero.cmd.OKPrx):

        def checkedCast(proxy, facetOrCtx=None, _ctx=None):
            return _M_omero.cmd.Delete2ResponsePrx.ice_checkedCast(proxy, '::omero::cmd::Delete2Response', facetOrCtx, _ctx)
        checkedCast = staticmethod(checkedCast)

        def uncheckedCast(proxy, facet=None):
            return _M_omero.cmd.Delete2ResponsePrx.ice_uncheckedCast(proxy, facet)
        uncheckedCast = staticmethod(uncheckedCast)

        def ice_staticId():
            return '::omero::cmd::Delete2Response'
        ice_staticId = staticmethod(ice_staticId)

    _M_omero.cmd._t_Delete2ResponsePrx = IcePy.defineProxy('::omero::cmd::Delete2Response', Delete2ResponsePrx)

    _M_omero.cmd._t_Delete2Response = IcePy.defineClass('::omero::cmd::Delete2Response', Delete2Response, -1, (), False, False, _M_omero.cmd._t_OK, (), (('deletedObjects', (), _M_omero.api._t_StringLongListMap, False, 0),))
    Delete2Response._ice_type = _M_omero.cmd._t_Delete2Response

    _M_omero.cmd.Delete2Response = Delete2Response
    del Delete2Response

    _M_omero.cmd.Delete2ResponsePrx = Delete2ResponsePrx
    del Delete2ResponsePrx

if 'SkipHead' not in _M_omero.cmd.__dict__:
    _M_omero.cmd.SkipHead = Ice.createTempClass()
    class SkipHead(_M_omero.cmd.GraphModify2):
        """
        Perform a request skipping the top-most model objects in the
        graph. This permits operating upon the (possibly indirect)
        children of given objects. The arguments of this SkipHead
        request override those of the given request only until the
        targeted children are reached, except that if this SkipHead
        request's dryRun is set to true then the dryRun override
        persists throughout the operation. The response from SkipHead
        is as from the given request.
        Members:
        startFrom -- Classes of model objects from which to actually start the
        operation. These are children, directly or indirectly, of
        the target objects. These children become the true target
        objects of the underlying request.
        request -- The operation to perform on the targeted model objects.
        The given request's targetObjects property is ignored: it
        is the SkipHead request that specifies the parent objects.
        Only specific request types are supported
        (those implementing WrappableRequest).
        """
        def __init__(self, targetObjects=None, childOptions=None, dryRun=False, startFrom=None, request=None):
            _M_omero.cmd.GraphModify2.__init__(self, targetObjects, childOptions, dryRun)
            self.startFrom = startFrom
            self.request = request

        def ice_ids(self, current=None):
            return ('::Ice::Object', '::omero::cmd::GraphModify2', '::omero::cmd::GraphQuery', '::omero::cmd::Request', '::omero::cmd::SkipHead')

        def ice_id(self, current=None):
            return '::omero::cmd::SkipHead'

        def ice_staticId():
            return '::omero::cmd::SkipHead'
        ice_staticId = staticmethod(ice_staticId)

        def __str__(self):
            return IcePy.stringify(self, _M_omero.cmd._t_SkipHead)

        __repr__ = __str__

    _M_omero.cmd.SkipHeadPrx = Ice.createTempClass()
    class SkipHeadPrx(_M_omero.cmd.GraphModify2Prx):

        def checkedCast(proxy, facetOrCtx=None, _ctx=None):
            return _M_omero.cmd.SkipHeadPrx.ice_checkedCast(proxy, '::omero::cmd::SkipHead', facetOrCtx, _ctx)
        checkedCast = staticmethod(checkedCast)

        def uncheckedCast(proxy, facet=None):
            return _M_omero.cmd.SkipHeadPrx.ice_uncheckedCast(proxy, facet)
        uncheckedCast = staticmethod(uncheckedCast)

        def ice_staticId():
            return '::omero::cmd::SkipHead'
        ice_staticId = staticmethod(ice_staticId)

    _M_omero.cmd._t_SkipHeadPrx = IcePy.defineProxy('::omero::cmd::SkipHead', SkipHeadPrx)

    _M_omero.cmd._t_SkipHead = IcePy.declareClass('::omero::cmd::SkipHead')

    _M_omero.cmd._t_SkipHead = IcePy.defineClass('::omero::cmd::SkipHead', SkipHead, -1, (), False, False, _M_omero.cmd._t_GraphModify2, (), (
        ('startFrom', (), _M_omero.api._t_StringSet, False, 0),
        ('request', (), _M_omero.cmd._t_GraphModify2, False, 0)
    ))
    SkipHead._ice_type = _M_omero.cmd._t_SkipHead

    _M_omero.cmd.SkipHead = SkipHead
    del SkipHead

    _M_omero.cmd.SkipHeadPrx = SkipHeadPrx
    del SkipHeadPrx

if 'DiskUsage2' not in _M_omero.cmd.__dict__:
    _M_omero.cmd.DiskUsage2 = Ice.createTempClass()
    class DiskUsage2(_M_omero.cmd.GraphQuery):
        """
        Request to determine the disk usage of the given objects
        and their contents. File-system paths used by multiple objects
        are de-duplicated in the total count. Specifying a class is
        equivalent to specifying all its instances as objects.
        Permissible classes include:
        ExperimenterGroup, Experimenter, Project, Dataset,
        Folder, Screen, Plate, Well, WellSample,
        Image, Pixels, Annotation, Job, Fileset, OriginalFile.
        """
        def __init__(self, targetObjects=None, targetClasses=None):
            _M_omero.cmd.GraphQuery.__init__(self, targetObjects)
            self.targetClasses = targetClasses

        def ice_ids(self, current=None):
            return ('::Ice::Object', '::omero::cmd::DiskUsage2', '::omero::cmd::GraphQuery', '::omero::cmd::Request')

        def ice_id(self, current=None):
            return '::omero::cmd::DiskUsage2'

        def ice_staticId():
            return '::omero::cmd::DiskUsage2'
        ice_staticId = staticmethod(ice_staticId)

        def __str__(self):
            return IcePy.stringify(self, _M_omero.cmd._t_DiskUsage2)

        __repr__ = __str__

    _M_omero.cmd.DiskUsage2Prx = Ice.createTempClass()
    class DiskUsage2Prx(_M_omero.cmd.GraphQueryPrx):

        def checkedCast(proxy, facetOrCtx=None, _ctx=None):
            return _M_omero.cmd.DiskUsage2Prx.ice_checkedCast(proxy, '::omero::cmd::DiskUsage2', facetOrCtx, _ctx)
        checkedCast = staticmethod(checkedCast)

        def uncheckedCast(proxy, facet=None):
            return _M_omero.cmd.DiskUsage2Prx.ice_uncheckedCast(proxy, facet)
        uncheckedCast = staticmethod(uncheckedCast)

        def ice_staticId():
            return '::omero::cmd::DiskUsage2'
        ice_staticId = staticmethod(ice_staticId)

    _M_omero.cmd._t_DiskUsage2Prx = IcePy.defineProxy('::omero::cmd::DiskUsage2', DiskUsage2Prx)

    _M_omero.cmd._t_DiskUsage2 = IcePy.defineClass('::omero::cmd::DiskUsage2', DiskUsage2, -1, (), False, False, _M_omero.cmd._t_GraphQuery, (), (('targetClasses', (), _M_omero.api._t_StringSet, False, 0),))
    DiskUsage2._ice_type = _M_omero.cmd._t_DiskUsage2

    _M_omero.cmd.DiskUsage2 = DiskUsage2
    del DiskUsage2

    _M_omero.cmd.DiskUsage2Prx = DiskUsage2Prx
    del DiskUsage2Prx

if 'DiskUsage2Response' not in _M_omero.cmd.__dict__:
    _M_omero.cmd.DiskUsage2Response = Ice.createTempClass()
    class DiskUsage2Response(_M_omero.cmd.OK):
        """
        Disk usage report: bytes used and non-empty file counts on the
        repository file-system for specific objects. The counts from the
        maps may sum to more than the total if different types of object
        refer to the same file. Common referers include:
        Annotation for file annotations
        FilesetEntry for OMERO 5 image files (OMERO.fs)
        Job for import logs
        Pixels for pyramids and OMERO 4 images and archived files
        Thumbnail for the image thumbnails
        The above map values are broken down by owner-group keys.
        """
        def __init__(self, fileCountByReferer=None, bytesUsedByReferer=None, totalFileCount=None, totalBytesUsed=None):
            _M_omero.cmd.OK.__init__(self)
            self.fileCountByReferer = fileCountByReferer
            self.bytesUsedByReferer = bytesUsedByReferer
            self.totalFileCount = totalFileCount
            self.totalBytesUsed = totalBytesUsed

        def ice_ids(self, current=None):
            return ('::Ice::Object', '::omero::cmd::DiskUsage2Response', '::omero::cmd::OK', '::omero::cmd::Response')

        def ice_id(self, current=None):
            return '::omero::cmd::DiskUsage2Response'

        def ice_staticId():
            return '::omero::cmd::DiskUsage2Response'
        ice_staticId = staticmethod(ice_staticId)

        def __str__(self):
            return IcePy.stringify(self, _M_omero.cmd._t_DiskUsage2Response)

        __repr__ = __str__

    _M_omero.cmd.DiskUsage2ResponsePrx = Ice.createTempClass()
    class DiskUsage2ResponsePrx(_M_omero.cmd.OKPrx):

        def checkedCast(proxy, facetOrCtx=None, _ctx=None):
            return _M_omero.cmd.DiskUsage2ResponsePrx.ice_checkedCast(proxy, '::omero::cmd::DiskUsage2Response', facetOrCtx, _ctx)
        checkedCast = staticmethod(checkedCast)

        def uncheckedCast(proxy, facet=None):
            return _M_omero.cmd.DiskUsage2ResponsePrx.ice_uncheckedCast(proxy, facet)
        uncheckedCast = staticmethod(uncheckedCast)

        def ice_staticId():
            return '::omero::cmd::DiskUsage2Response'
        ice_staticId = staticmethod(ice_staticId)

    _M_omero.cmd._t_DiskUsage2ResponsePrx = IcePy.defineProxy('::omero::cmd::DiskUsage2Response', DiskUsage2ResponsePrx)

    _M_omero.cmd._t_DiskUsage2Response = IcePy.defineClass('::omero::cmd::DiskUsage2Response', DiskUsage2Response, -1, (), False, False, _M_omero.cmd._t_OK, (), (
        ('fileCountByReferer', (), _M_omero.api._t_LongPairToStringIntMap, False, 0),
        ('bytesUsedByReferer', (), _M_omero.api._t_LongPairToStringLongMap, False, 0),
        ('totalFileCount', (), _M_omero.api._t_LongPairIntMap, False, 0),
        ('totalBytesUsed', (), _M_omero.api._t_LongPairLongMap, False, 0)
    ))
    DiskUsage2Response._ice_type = _M_omero.cmd._t_DiskUsage2Response

    _M_omero.cmd.DiskUsage2Response = DiskUsage2Response
    del DiskUsage2Response

    _M_omero.cmd.DiskUsage2ResponsePrx = DiskUsage2ResponsePrx
    del DiskUsage2ResponsePrx

if 'Duplicate' not in _M_omero.cmd.__dict__:
    _M_omero.cmd.Duplicate = Ice.createTempClass()
    class Duplicate(_M_omero.cmd.GraphModify2):
        """
        Duplicate model objects with some selection of their subgraph.
        All target model objects must be in the current group context.
        The extra three data members allow adjustment of the related
        subgraph. The same type must not be listed in more than one of
        those data members. Use of a more specific sub-type in a data
        member always overrides the more general type in another.
        Members:
        typesToDuplicate -- The types of the model objects to actually duplicate.
        typesToReference -- The types of the model objects that should not be duplicated
        but that may participate in references involving duplicates.
        typesToIgnore -- The types of the model objects that should not be duplicated
        and that may not participate in references involving duplicates.
        """
        def __init__(self, targetObjects=None, childOptions=None, dryRun=False, typesToDuplicate=None, typesToReference=None, typesToIgnore=None):
            _M_omero.cmd.GraphModify2.__init__(self, targetObjects, childOptions, dryRun)
            self.typesToDuplicate = typesToDuplicate
            self.typesToReference = typesToReference
            self.typesToIgnore = typesToIgnore

        def ice_ids(self, current=None):
            return ('::Ice::Object', '::omero::cmd::Duplicate', '::omero::cmd::GraphModify2', '::omero::cmd::GraphQuery', '::omero::cmd::Request')

        def ice_id(self, current=None):
            return '::omero::cmd::Duplicate'

        def ice_staticId():
            return '::omero::cmd::Duplicate'
        ice_staticId = staticmethod(ice_staticId)

        def __str__(self):
            return IcePy.stringify(self, _M_omero.cmd._t_Duplicate)

        __repr__ = __str__

    _M_omero.cmd.DuplicatePrx = Ice.createTempClass()
    class DuplicatePrx(_M_omero.cmd.GraphModify2Prx):

        def checkedCast(proxy, facetOrCtx=None, _ctx=None):
            return _M_omero.cmd.DuplicatePrx.ice_checkedCast(proxy, '::omero::cmd::Duplicate', facetOrCtx, _ctx)
        checkedCast = staticmethod(checkedCast)

        def uncheckedCast(proxy, facet=None):
            return _M_omero.cmd.DuplicatePrx.ice_uncheckedCast(proxy, facet)
        uncheckedCast = staticmethod(uncheckedCast)

        def ice_staticId():
            return '::omero::cmd::Duplicate'
        ice_staticId = staticmethod(ice_staticId)

    _M_omero.cmd._t_DuplicatePrx = IcePy.defineProxy('::omero::cmd::Duplicate', DuplicatePrx)

    _M_omero.cmd._t_Duplicate = IcePy.declareClass('::omero::cmd::Duplicate')

    _M_omero.cmd._t_Duplicate = IcePy.defineClass('::omero::cmd::Duplicate', Duplicate, -1, (), False, False, _M_omero.cmd._t_GraphModify2, (), (
        ('typesToDuplicate', (), _M_omero.api._t_StringSet, False, 0),
        ('typesToReference', (), _M_omero.api._t_StringSet, False, 0),
        ('typesToIgnore', (), _M_omero.api._t_StringSet, False, 0)
    ))
    Duplicate._ice_type = _M_omero.cmd._t_Duplicate

    _M_omero.cmd.Duplicate = Duplicate
    del Duplicate

    _M_omero.cmd.DuplicatePrx = DuplicatePrx
    del DuplicatePrx

if 'DuplicateResponse' not in _M_omero.cmd.__dict__:
    _M_omero.cmd.DuplicateResponse = Ice.createTempClass()
    class DuplicateResponse(_M_omero.cmd.OK):
        """
        Result of duplicating model objects.
        Members:
        duplicates -- The duplicate model objects created by the request.
        Note: If dryRun is set to true then this instead lists the model
        objects that would have been duplicated.
        """
        def __init__(self, duplicates=None):
            _M_omero.cmd.OK.__init__(self)
            self.duplicates = duplicates

        def ice_ids(self, current=None):
            return ('::Ice::Object', '::omero::cmd::DuplicateResponse', '::omero::cmd::OK', '::omero::cmd::Response')

        def ice_id(self, current=None):
            return '::omero::cmd::DuplicateResponse'

        def ice_staticId():
            return '::omero::cmd::DuplicateResponse'
        ice_staticId = staticmethod(ice_staticId)

        def __str__(self):
            return IcePy.stringify(self, _M_omero.cmd._t_DuplicateResponse)

        __repr__ = __str__

    _M_omero.cmd.DuplicateResponsePrx = Ice.createTempClass()
    class DuplicateResponsePrx(_M_omero.cmd.OKPrx):

        def checkedCast(proxy, facetOrCtx=None, _ctx=None):
            return _M_omero.cmd.DuplicateResponsePrx.ice_checkedCast(proxy, '::omero::cmd::DuplicateResponse', facetOrCtx, _ctx)
        checkedCast = staticmethod(checkedCast)

        def uncheckedCast(proxy, facet=None):
            return _M_omero.cmd.DuplicateResponsePrx.ice_uncheckedCast(proxy, facet)
        uncheckedCast = staticmethod(uncheckedCast)

        def ice_staticId():
            return '::omero::cmd::DuplicateResponse'
        ice_staticId = staticmethod(ice_staticId)

    _M_omero.cmd._t_DuplicateResponsePrx = IcePy.defineProxy('::omero::cmd::DuplicateResponse', DuplicateResponsePrx)

    _M_omero.cmd._t_DuplicateResponse = IcePy.defineClass('::omero::cmd::DuplicateResponse', DuplicateResponse, -1, (), False, False, _M_omero.cmd._t_OK, (), (('duplicates', (), _M_omero.api._t_StringLongListMap, False, 0),))
    DuplicateResponse._ice_type = _M_omero.cmd._t_DuplicateResponse

    _M_omero.cmd.DuplicateResponse = DuplicateResponse
    del DuplicateResponse

    _M_omero.cmd.DuplicateResponsePrx = DuplicateResponsePrx
    del DuplicateResponsePrx

if 'FindParents' not in _M_omero.cmd.__dict__:
    _M_omero.cmd.FindParents = Ice.createTempClass()
    class FindParents(_M_omero.cmd.GraphQuery):
        """
        Identify the parents or containers of model objects.
        Traverses the model graph to identify indirect relationships.
        Members:
        typesOfParents -- The types of parents being sought.
        stopBefore -- Classes of model objects to exclude from the recursive
        search. Search does not include or pass such objects.
        For efficiency the server automatically excludes various
        classes depending on the other arguments of the request.
        """
        def __init__(self, targetObjects=None, typesOfParents=None, stopBefore=None):
            _M_omero.cmd.GraphQuery.__init__(self, targetObjects)
            self.typesOfParents = typesOfParents
            self.stopBefore = stopBefore

        def ice_ids(self, current=None):
            return ('::Ice::Object', '::omero::cmd::FindParents', '::omero::cmd::GraphQuery', '::omero::cmd::Request')

        def ice_id(self, current=None):
            return '::omero::cmd::FindParents'

        def ice_staticId():
            return '::omero::cmd::FindParents'
        ice_staticId = staticmethod(ice_staticId)

        def __str__(self):
            return IcePy.stringify(self, _M_omero.cmd._t_FindParents)

        __repr__ = __str__

    _M_omero.cmd.FindParentsPrx = Ice.createTempClass()
    class FindParentsPrx(_M_omero.cmd.GraphQueryPrx):

        def checkedCast(proxy, facetOrCtx=None, _ctx=None):
            return _M_omero.cmd.FindParentsPrx.ice_checkedCast(proxy, '::omero::cmd::FindParents', facetOrCtx, _ctx)
        checkedCast = staticmethod(checkedCast)

        def uncheckedCast(proxy, facet=None):
            return _M_omero.cmd.FindParentsPrx.ice_uncheckedCast(proxy, facet)
        uncheckedCast = staticmethod(uncheckedCast)

        def ice_staticId():
            return '::omero::cmd::FindParents'
        ice_staticId = staticmethod(ice_staticId)

    _M_omero.cmd._t_FindParentsPrx = IcePy.defineProxy('::omero::cmd::FindParents', FindParentsPrx)

    _M_omero.cmd._t_FindParents = IcePy.defineClass('::omero::cmd::FindParents', FindParents, -1, (), False, False, _M_omero.cmd._t_GraphQuery, (), (
        ('typesOfParents', (), _M_omero.api._t_StringSet, False, 0),
        ('stopBefore', (), _M_omero.api._t_StringSet, False, 0)
    ))
    FindParents._ice_type = _M_omero.cmd._t_FindParents

    _M_omero.cmd.FindParents = FindParents
    del FindParents

    _M_omero.cmd.FindParentsPrx = FindParentsPrx
    del FindParentsPrx

if 'FoundParents' not in _M_omero.cmd.__dict__:
    _M_omero.cmd.FoundParents = Ice.createTempClass()
    class FoundParents(_M_omero.cmd.OK):
        """
        Result of identifying the parents or containers of model objects.
        Members:
        parents -- The parents that were identified.
        """
        def __init__(self, parents=None):
            _M_omero.cmd.OK.__init__(self)
            self.parents = parents

        def ice_ids(self, current=None):
            return ('::Ice::Object', '::omero::cmd::FoundParents', '::omero::cmd::OK', '::omero::cmd::Response')

        def ice_id(self, current=None):
            return '::omero::cmd::FoundParents'

        def ice_staticId():
            return '::omero::cmd::FoundParents'
        ice_staticId = staticmethod(ice_staticId)

        def __str__(self):
            return IcePy.stringify(self, _M_omero.cmd._t_FoundParents)

        __repr__ = __str__

    _M_omero.cmd.FoundParentsPrx = Ice.createTempClass()
    class FoundParentsPrx(_M_omero.cmd.OKPrx):

        def checkedCast(proxy, facetOrCtx=None, _ctx=None):
            return _M_omero.cmd.FoundParentsPrx.ice_checkedCast(proxy, '::omero::cmd::FoundParents', facetOrCtx, _ctx)
        checkedCast = staticmethod(checkedCast)

        def uncheckedCast(proxy, facet=None):
            return _M_omero.cmd.FoundParentsPrx.ice_uncheckedCast(proxy, facet)
        uncheckedCast = staticmethod(uncheckedCast)

        def ice_staticId():
            return '::omero::cmd::FoundParents'
        ice_staticId = staticmethod(ice_staticId)

    _M_omero.cmd._t_FoundParentsPrx = IcePy.defineProxy('::omero::cmd::FoundParents', FoundParentsPrx)

    _M_omero.cmd._t_FoundParents = IcePy.defineClass('::omero::cmd::FoundParents', FoundParents, -1, (), False, False, _M_omero.cmd._t_OK, (), (('parents', (), _M_omero.api._t_StringLongListMap, False, 0),))
    FoundParents._ice_type = _M_omero.cmd._t_FoundParents

    _M_omero.cmd.FoundParents = FoundParents
    del FoundParents

    _M_omero.cmd.FoundParentsPrx = FoundParentsPrx
    del FoundParentsPrx

if 'FindChildren' not in _M_omero.cmd.__dict__:
    _M_omero.cmd.FindChildren = Ice.createTempClass()
    class FindChildren(_M_omero.cmd.GraphQuery):
        """
        Identify the children or contents of model objects.
        Traverses the model graph to identify indirect relationships.
        Members:
        typesOfChildren -- The types of children being sought.
        stopBefore -- Classes of model objects to exclude from the recursive
        search. Search does not include or pass such objects.
        For efficiency the server automatically excludes various
        classes depending on the other arguments of the request.
        """
        def __init__(self, targetObjects=None, typesOfChildren=None, stopBefore=None):
            _M_omero.cmd.GraphQuery.__init__(self, targetObjects)
            self.typesOfChildren = typesOfChildren
            self.stopBefore = stopBefore

        def ice_ids(self, current=None):
            return ('::Ice::Object', '::omero::cmd::FindChildren', '::omero::cmd::GraphQuery', '::omero::cmd::Request')

        def ice_id(self, current=None):
            return '::omero::cmd::FindChildren'

        def ice_staticId():
            return '::omero::cmd::FindChildren'
        ice_staticId = staticmethod(ice_staticId)

        def __str__(self):
            return IcePy.stringify(self, _M_omero.cmd._t_FindChildren)

        __repr__ = __str__

    _M_omero.cmd.FindChildrenPrx = Ice.createTempClass()
    class FindChildrenPrx(_M_omero.cmd.GraphQueryPrx):

        def checkedCast(proxy, facetOrCtx=None, _ctx=None):
            return _M_omero.cmd.FindChildrenPrx.ice_checkedCast(proxy, '::omero::cmd::FindChildren', facetOrCtx, _ctx)
        checkedCast = staticmethod(checkedCast)

        def uncheckedCast(proxy, facet=None):
            return _M_omero.cmd.FindChildrenPrx.ice_uncheckedCast(proxy, facet)
        uncheckedCast = staticmethod(uncheckedCast)

        def ice_staticId():
            return '::omero::cmd::FindChildren'
        ice_staticId = staticmethod(ice_staticId)

    _M_omero.cmd._t_FindChildrenPrx = IcePy.defineProxy('::omero::cmd::FindChildren', FindChildrenPrx)

    _M_omero.cmd._t_FindChildren = IcePy.defineClass('::omero::cmd::FindChildren', FindChildren, -1, (), False, False, _M_omero.cmd._t_GraphQuery, (), (
        ('typesOfChildren', (), _M_omero.api._t_StringSet, False, 0),
        ('stopBefore', (), _M_omero.api._t_StringSet, False, 0)
    ))
    FindChildren._ice_type = _M_omero.cmd._t_FindChildren

    _M_omero.cmd.FindChildren = FindChildren
    del FindChildren

    _M_omero.cmd.FindChildrenPrx = FindChildrenPrx
    del FindChildrenPrx

if 'FoundChildren' not in _M_omero.cmd.__dict__:
    _M_omero.cmd.FoundChildren = Ice.createTempClass()
    class FoundChildren(_M_omero.cmd.OK):
        """
        Result of identifying the children or contents of model objects.
        Members:
        children -- The children that were identified.
        """
        def __init__(self, children=None):
            _M_omero.cmd.OK.__init__(self)
            self.children = children

        def ice_ids(self, current=None):
            return ('::Ice::Object', '::omero::cmd::FoundChildren', '::omero::cmd::OK', '::omero::cmd::Response')

        def ice_id(self, current=None):
            return '::omero::cmd::FoundChildren'

        def ice_staticId():
            return '::omero::cmd::FoundChildren'
        ice_staticId = staticmethod(ice_staticId)

        def __str__(self):
            return IcePy.stringify(self, _M_omero.cmd._t_FoundChildren)

        __repr__ = __str__

    _M_omero.cmd.FoundChildrenPrx = Ice.createTempClass()
    class FoundChildrenPrx(_M_omero.cmd.OKPrx):

        def checkedCast(proxy, facetOrCtx=None, _ctx=None):
            return _M_omero.cmd.FoundChildrenPrx.ice_checkedCast(proxy, '::omero::cmd::FoundChildren', facetOrCtx, _ctx)
        checkedCast = staticmethod(checkedCast)

        def uncheckedCast(proxy, facet=None):
            return _M_omero.cmd.FoundChildrenPrx.ice_uncheckedCast(proxy, facet)
        uncheckedCast = staticmethod(uncheckedCast)

        def ice_staticId():
            return '::omero::cmd::FoundChildren'
        ice_staticId = staticmethod(ice_staticId)

    _M_omero.cmd._t_FoundChildrenPrx = IcePy.defineProxy('::omero::cmd::FoundChildren', FoundChildrenPrx)

    _M_omero.cmd._t_FoundChildren = IcePy.defineClass('::omero::cmd::FoundChildren', FoundChildren, -1, (), False, False, _M_omero.cmd._t_OK, (), (('children', (), _M_omero.api._t_StringLongListMap, False, 0),))
    FoundChildren._ice_type = _M_omero.cmd._t_FoundChildren

    _M_omero.cmd.FoundChildren = FoundChildren
    del FoundChildren

    _M_omero.cmd.FoundChildrenPrx = FoundChildrenPrx
    del FoundChildrenPrx

if 'LegalGraphTargets' not in _M_omero.cmd.__dict__:
    _M_omero.cmd.LegalGraphTargets = Ice.createTempClass()
    class LegalGraphTargets(_M_omero.cmd.Request):
        """
        Graph requests typically allow only specific model object classes
        to be targeted. This request lists the legal targets for a given
        request. The request's fields are ignored, only its class matters.
        Members:
        request -- A request of the type being queried.
        """
        def __init__(self, request=None):
            _M_omero.cmd.Request.__init__(self)
            self.request = request

        def ice_ids(self, current=None):
            return ('::Ice::Object', '::omero::cmd::LegalGraphTargets', '::omero::cmd::Request')

        def ice_id(self, current=None):
            return '::omero::cmd::LegalGraphTargets'

        def ice_staticId():
            return '::omero::cmd::LegalGraphTargets'
        ice_staticId = staticmethod(ice_staticId)

        def __str__(self):
            return IcePy.stringify(self, _M_omero.cmd._t_LegalGraphTargets)

        __repr__ = __str__

    _M_omero.cmd.LegalGraphTargetsPrx = Ice.createTempClass()
    class LegalGraphTargetsPrx(_M_omero.cmd.RequestPrx):

        def checkedCast(proxy, facetOrCtx=None, _ctx=None):
            return _M_omero.cmd.LegalGraphTargetsPrx.ice_checkedCast(proxy, '::omero::cmd::LegalGraphTargets', facetOrCtx, _ctx)
        checkedCast = staticmethod(checkedCast)

        def uncheckedCast(proxy, facet=None):
            return _M_omero.cmd.LegalGraphTargetsPrx.ice_uncheckedCast(proxy, facet)
        uncheckedCast = staticmethod(uncheckedCast)

        def ice_staticId():
            return '::omero::cmd::LegalGraphTargets'
        ice_staticId = staticmethod(ice_staticId)

    _M_omero.cmd._t_LegalGraphTargetsPrx = IcePy.defineProxy('::omero::cmd::LegalGraphTargets', LegalGraphTargetsPrx)

    _M_omero.cmd._t_LegalGraphTargets = IcePy.declareClass('::omero::cmd::LegalGraphTargets')

    _M_omero.cmd._t_LegalGraphTargets = IcePy.defineClass('::omero::cmd::LegalGraphTargets', LegalGraphTargets, -1, (), False, False, _M_omero.cmd._t_Request, (), (('request', (), _M_omero.cmd._t_GraphQuery, False, 0),))
    LegalGraphTargets._ice_type = _M_omero.cmd._t_LegalGraphTargets

    _M_omero.cmd.LegalGraphTargets = LegalGraphTargets
    del LegalGraphTargets

    _M_omero.cmd.LegalGraphTargetsPrx = LegalGraphTargetsPrx
    del LegalGraphTargetsPrx

if 'LegalGraphTargetsResponse' not in _M_omero.cmd.__dict__:
    _M_omero.cmd.LegalGraphTargetsResponse = Ice.createTempClass()
    class LegalGraphTargetsResponse(_M_omero.cmd.OK):
        """
        A list of the legal targets for a graph request.
        Members:
        targets -- The legal targets for the given request's type.
        """
        def __init__(self, targets=None):
            _M_omero.cmd.OK.__init__(self)
            self.targets = targets

        def ice_ids(self, current=None):
            return ('::Ice::Object', '::omero::cmd::LegalGraphTargetsResponse', '::omero::cmd::OK', '::omero::cmd::Response')

        def ice_id(self, current=None):
            return '::omero::cmd::LegalGraphTargetsResponse'

        def ice_staticId():
            return '::omero::cmd::LegalGraphTargetsResponse'
        ice_staticId = staticmethod(ice_staticId)

        def __str__(self):
            return IcePy.stringify(self, _M_omero.cmd._t_LegalGraphTargetsResponse)

        __repr__ = __str__

    _M_omero.cmd.LegalGraphTargetsResponsePrx = Ice.createTempClass()
    class LegalGraphTargetsResponsePrx(_M_omero.cmd.OKPrx):

        def checkedCast(proxy, facetOrCtx=None, _ctx=None):
            return _M_omero.cmd.LegalGraphTargetsResponsePrx.ice_checkedCast(proxy, '::omero::cmd::LegalGraphTargetsResponse', facetOrCtx, _ctx)
        checkedCast = staticmethod(checkedCast)

        def uncheckedCast(proxy, facet=None):
            return _M_omero.cmd.LegalGraphTargetsResponsePrx.ice_uncheckedCast(proxy, facet)
        uncheckedCast = staticmethod(uncheckedCast)

        def ice_staticId():
            return '::omero::cmd::LegalGraphTargetsResponse'
        ice_staticId = staticmethod(ice_staticId)

    _M_omero.cmd._t_LegalGraphTargetsResponsePrx = IcePy.defineProxy('::omero::cmd::LegalGraphTargetsResponse', LegalGraphTargetsResponsePrx)

    _M_omero.cmd._t_LegalGraphTargetsResponse = IcePy.defineClass('::omero::cmd::LegalGraphTargetsResponse', LegalGraphTargetsResponse, -1, (), False, False, _M_omero.cmd._t_OK, (), (('targets', (), _M_omero.api._t_StringSet, False, 0),))
    LegalGraphTargetsResponse._ice_type = _M_omero.cmd._t_LegalGraphTargetsResponse

    _M_omero.cmd.LegalGraphTargetsResponse = LegalGraphTargetsResponse
    del LegalGraphTargetsResponse

    _M_omero.cmd.LegalGraphTargetsResponsePrx = LegalGraphTargetsResponsePrx
    del LegalGraphTargetsResponsePrx

if 'GraphException' not in _M_omero.cmd.__dict__:
    _M_omero.cmd.GraphException = Ice.createTempClass()
    class GraphException(_M_omero.cmd.ERR):
        """
        Returned when specifically a ome.services.graphs.GraphException
        is thrown. The contents of that internal exception are passed in
        this instance.
        Members:
        message -- The message of the GraphException.
        """
        def __init__(self, category='', name='', parameters=None, message=''):
            _M_omero.cmd.ERR.__init__(self, category, name, parameters)
            self.message = message

        def ice_ids(self, current=None):
            return ('::Ice::Object', '::omero::cmd::ERR', '::omero::cmd::GraphException', '::omero::cmd::Response')

        def ice_id(self, current=None):
            return '::omero::cmd::GraphException'

        def ice_staticId():
            return '::omero::cmd::GraphException'
        ice_staticId = staticmethod(ice_staticId)

        def __str__(self):
            return IcePy.stringify(self, _M_omero.cmd._t_GraphException)

        __repr__ = __str__

    _M_omero.cmd.GraphExceptionPrx = Ice.createTempClass()
    class GraphExceptionPrx(_M_omero.cmd.ERRPrx):

        def checkedCast(proxy, facetOrCtx=None, _ctx=None):
            return _M_omero.cmd.GraphExceptionPrx.ice_checkedCast(proxy, '::omero::cmd::GraphException', facetOrCtx, _ctx)
        checkedCast = staticmethod(checkedCast)

        def uncheckedCast(proxy, facet=None):
            return _M_omero.cmd.GraphExceptionPrx.ice_uncheckedCast(proxy, facet)
        uncheckedCast = staticmethod(uncheckedCast)

        def ice_staticId():
            return '::omero::cmd::GraphException'
        ice_staticId = staticmethod(ice_staticId)

    _M_omero.cmd._t_GraphExceptionPrx = IcePy.defineProxy('::omero::cmd::GraphException', GraphExceptionPrx)

    _M_omero.cmd._t_GraphException = IcePy.defineClass('::omero::cmd::GraphException', GraphException, -1, (), False, False, _M_omero.cmd._t_ERR, (), (('message', (), IcePy._t_string, False, 0),))
    GraphException._ice_type = _M_omero.cmd._t_GraphException

    _M_omero.cmd.GraphException = GraphException
    del GraphException

    _M_omero.cmd.GraphExceptionPrx = GraphExceptionPrx
    del GraphExceptionPrx

# End of module omero.cmd

__name__ = 'omero'

# End of module omero



# -*- coding: utf-8 -*-
# **********************************************************************
#
# Copyright (c) 2003-2017 ZeroC, Inc. All rights reserved.
#
# This copy of Ice is licensed to you under the terms described in the
# ICE_LICENSE file included in this distribution.
#
# **********************************************************************
#
# Ice version 3.6.4
#
# <auto-generated>
#
# Generated from file `ServerErrors.ice'
#
# Warning: do not edit this file.
#
# </auto-generated>
#

from sys import version_info as _version_info_
import Ice, IcePy
import Glacier2_Session_ice
import omero_Collections_ice

# Included module Ice
_M_Ice = Ice.openModule('Ice')

# Included module Glacier2
_M_Glacier2 = Ice.openModule('Glacier2')

# Included module omero
_M_omero = Ice.openModule('omero')

# Included module omero.model
_M_omero.model = Ice.openModule('omero.model')

# Included module omero.sys
_M_omero.sys = Ice.openModule('omero.sys')

# Included module omero.api
_M_omero.api = Ice.openModule('omero.api')

# Start of module omero
__name__ = 'omero'
_M_omero.__doc__ = """
Exceptions thrown by OMERO server components. Exceptions thrown client side
are available defined in each language binding separately, but will usually
subclass from "ClientError" For more information, see:
https://trac.openmicroscopy.org.uk/ome/wiki/ExceptionHandling
including examples of what a appropriate try/catch block would look like.
All exceptions that are thrown by a remote call (any call on a *Prx instance)
will be either a subclass of Ice.UserException or Ice.LocalException.
Inheritance Hierarchy for Exceptions
from the Ice manual shows the entire exception hierarchy. The exceptions described in
this file will subclass from Ice.UserException. Other Ice-runtime exceptions subclass
from Ice.LocalException.
OMERO Specific:
===============
ServerError (root server exception)
|
|_ InternalException (server bug)
|
|_ ResourceError (non-recoverable)
|  \_ NoProcessorAvailable
|
|_ ConcurrencyException (recoverable)
|  |_ ConcurrentModification (data was changed)
|  |_ OptimisticLockException (changed data conflicts)
|  |_ LockTimeout (took too long to aquire lock)
|  |_ TryAgain (some processing required before server is ready)
|  \_ TooManyUsersException
|     \_ DatabaseBusyException
|
|_ ApiUsageException (misuse of services)
|   |_ OverUsageException (too much)
|   |_ QueryException (bad query string)
|   |_ ValidationException (bad data)
|      |_ ChecksumValidationException (checksum mismatch)
|      \_ FilePathNamingException (repository path badly named)
|
|_ SecurityViolation (some no-no)
|   \_ GroupSecurityViolation
|      |_ PermissionMismatchGroupSecurityViolation
|      \_ ReadOnlyGroupSecurityViolation
|
\_SessionException
|_ RemovedSessionException (accessing a non-extant session)
|_ SessionTimeoutException (session timed out; not yet removed)
\_ ShutdownInProgress      (session on this server will most likely be destroyed)
However, in addition to Ice.LocalException subclasses, the Ice runtime also
defines subclasses of Ice.UserException. In some cases, OMERO subclasses
from these exceptions. The subclasses shown below are not exhaustive, but show those
which an application's exception handler may want to deal with.
Ice::Exception (root of all Ice exceptions)
|
|_ Ice::UserException (super class of all application exceptions)
|  |
|  |_ Glacier2::CannotCreateSessionException (1 of 2 exceptions throwable by createSession)
|  |   |_ omero::AuthenticationException (bad login)
|  |   |_ omero::ExpiredCredentialException (old password)
|  |   |_ omero::WrappedCreateSessionException (any other server error during createSession)
|  |   \_ omero::licenses::NoAvailableLicensesException (see tools/licenses/resources/omero/LicensesAPI.ice)
|  |
|  \_ Glacier2::PermissionDeniedException (other of 2 exceptions throwable by createSession)
|
\_ Ice::LocalException (should generally be considered fatal. See exceptions below)
|
|_ Ice::ProtocolException (something went wrong on the wire. Wrong version?)
|
|_ Ice::RequestFailedException
|   |_ ObjectNotExistException (Service timeout or similar?)
|   \_ OperationNotExistException (Improper use of uncheckedCast?)
|
|_ Ice::UnknownException (server threw an unexpected exception. Bug!)
|
\_ Ice::TimeoutException
\_ Ice::ConnectTimeoutException (Couldn't establish a connection. Retry?)
"""

if 'ServerError' not in _M_omero.__dict__:
    _M_omero.ServerError = Ice.createTempClass()
    class ServerError(Ice.UserException):
        def __init__(self, serverStackTrace='', serverExceptionClass='', message=''):
            self.serverStackTrace = serverStackTrace
            self.serverExceptionClass = serverExceptionClass
            self.message = message

        def __str__(self):
            return IcePy.stringifyException(self)

        __repr__ = __str__

        _ice_name = 'omero::ServerError'

    _M_omero._t_ServerError = IcePy.defineException('::omero::ServerError', ServerError, (), False, None, (
        ('serverStackTrace', (), IcePy._t_string, False, 0),
        ('serverExceptionClass', (), IcePy._t_string, False, 0),
        ('message', (), IcePy._t_string, False, 0)
    ))
    ServerError._ice_type = _M_omero._t_ServerError

    _M_omero.ServerError = ServerError
    del ServerError

if 'SessionException' not in _M_omero.__dict__:
    _M_omero.SessionException = Ice.createTempClass()
    class SessionException(_M_omero.ServerError):
        """
        Base session exception, though in the OMERO.blitz
        implementation, all exceptions thrown by the Glacier2
        must subclass CannotCreateSessionException. See below.
        """
        def __init__(self, serverStackTrace='', serverExceptionClass='', message=''):
            _M_omero.ServerError.__init__(self, serverStackTrace, serverExceptionClass, message)

        def __str__(self):
            return IcePy.stringifyException(self)

        __repr__ = __str__

        _ice_name = 'omero::SessionException'

    _M_omero._t_SessionException = IcePy.defineException('::omero::SessionException', SessionException, (), False, _M_omero._t_ServerError, ())
    SessionException._ice_type = _M_omero._t_SessionException

    _M_omero.SessionException = SessionException
    del SessionException

if 'RemovedSessionException' not in _M_omero.__dict__:
    _M_omero.RemovedSessionException = Ice.createTempClass()
    class RemovedSessionException(_M_omero.SessionException):
        """
        Session has been removed. Either it was closed, or it
        timed out and one "SessionTimeoutException" has already
        been thrown.
        """
        def __init__(self, serverStackTrace='', serverExceptionClass='', message=''):
            _M_omero.SessionException.__init__(self, serverStackTrace, serverExceptionClass, message)

        def __str__(self):
            return IcePy.stringifyException(self)

        __repr__ = __str__

        _ice_name = 'omero::RemovedSessionException'

    _M_omero._t_RemovedSessionException = IcePy.defineException('::omero::RemovedSessionException', RemovedSessionException, (), False, _M_omero._t_SessionException, ())
    RemovedSessionException._ice_type = _M_omero._t_RemovedSessionException

    _M_omero.RemovedSessionException = RemovedSessionException
    del RemovedSessionException

if 'SessionTimeoutException' not in _M_omero.__dict__:
    _M_omero.SessionTimeoutException = Ice.createTempClass()
    class SessionTimeoutException(_M_omero.SessionException):
        """
        Session has timed out and will be removed.
        """
        def __init__(self, serverStackTrace='', serverExceptionClass='', message=''):
            _M_omero.SessionException.__init__(self, serverStackTrace, serverExceptionClass, message)

        def __str__(self):
            return IcePy.stringifyException(self)

        __repr__ = __str__

        _ice_name = 'omero::SessionTimeoutException'

    _M_omero._t_SessionTimeoutException = IcePy.defineException('::omero::SessionTimeoutException', SessionTimeoutException, (), False, _M_omero._t_SessionException, ())
    SessionTimeoutException._ice_type = _M_omero._t_SessionTimeoutException

    _M_omero.SessionTimeoutException = SessionTimeoutException
    del SessionTimeoutException

if 'ShutdownInProgress' not in _M_omero.__dict__:
    _M_omero.ShutdownInProgress = Ice.createTempClass()
    class ShutdownInProgress(_M_omero.SessionException):
        """
        Server is in the progress of shutting down which will
        typically lead to the current session being closed.
        """
        def __init__(self, serverStackTrace='', serverExceptionClass='', message=''):
            _M_omero.SessionException.__init__(self, serverStackTrace, serverExceptionClass, message)

        def __str__(self):
            return IcePy.stringifyException(self)

        __repr__ = __str__

        _ice_name = 'omero::ShutdownInProgress'

    _M_omero._t_ShutdownInProgress = IcePy.defineException('::omero::ShutdownInProgress', ShutdownInProgress, (), False, _M_omero._t_SessionException, ())
    ShutdownInProgress._ice_type = _M_omero._t_ShutdownInProgress

    _M_omero.ShutdownInProgress = ShutdownInProgress
    del ShutdownInProgress

if 'AuthenticationException' not in _M_omero.__dict__:
    _M_omero.AuthenticationException = Ice.createTempClass()
    class AuthenticationException(_M_Glacier2.CannotCreateSessionException):
        """
        Thrown when the information provided omero.createSession() or more
        specifically Glacier2.RouterPrx.createSession() is incorrect. This
        does -not- subclass from the omero.ServerError class because the
        Ice Glacier2::SessionManager interface can only throw CCSEs.
        """
        def __init__(self, reason=''):
            _M_Glacier2.CannotCreateSessionException.__init__(self, reason)

        def __str__(self):
            return IcePy.stringifyException(self)

        __repr__ = __str__

        _ice_name = 'omero::AuthenticationException'

    _M_omero._t_AuthenticationException = IcePy.defineException('::omero::AuthenticationException', AuthenticationException, (), True, _M_Glacier2._t_CannotCreateSessionException, ())
    AuthenticationException._ice_type = _M_omero._t_AuthenticationException

    _M_omero.AuthenticationException = AuthenticationException
    del AuthenticationException

if 'ExpiredCredentialException' not in _M_omero.__dict__:
    _M_omero.ExpiredCredentialException = Ice.createTempClass()
    class ExpiredCredentialException(_M_Glacier2.CannotCreateSessionException):
        """
        Thrown when the password for a user has expired. Use: ISession.changeExpiredCredentials()
        and login as guest. This does -not- subclass from the omero.ServerError class because the
        Ice Glacier2::SessionManager interface can only throw CCSEs.
        """
        def __init__(self, reason=''):
            _M_Glacier2.CannotCreateSessionException.__init__(self, reason)

        def __str__(self):
            return IcePy.stringifyException(self)

        __repr__ = __str__

        _ice_name = 'omero::ExpiredCredentialException'

    _M_omero._t_ExpiredCredentialException = IcePy.defineException('::omero::ExpiredCredentialException', ExpiredCredentialException, (), True, _M_Glacier2._t_CannotCreateSessionException, ())
    ExpiredCredentialException._ice_type = _M_omero._t_ExpiredCredentialException

    _M_omero.ExpiredCredentialException = ExpiredCredentialException
    del ExpiredCredentialException

if 'WrappedCreateSessionException' not in _M_omero.__dict__:
    _M_omero.WrappedCreateSessionException = Ice.createTempClass()
    class WrappedCreateSessionException(_M_Glacier2.CannotCreateSessionException):
        """
        Thrown when any other server exception causes the session creation to fail.
        Since working with the static information of Ice exceptions is not as easy
        as with classes, here we use booleans to represent what has gone wrong.
        """
        def __init__(self, reason='', concurrency=False, backOff=0, type=''):
            _M_Glacier2.CannotCreateSessionException.__init__(self, reason)
            self.concurrency = concurrency
            self.backOff = backOff
            self.type = type

        def __str__(self):
            return IcePy.stringifyException(self)

        __repr__ = __str__

        _ice_name = 'omero::WrappedCreateSessionException'

    _M_omero._t_WrappedCreateSessionException = IcePy.defineException('::omero::WrappedCreateSessionException', WrappedCreateSessionException, (), True, _M_Glacier2._t_CannotCreateSessionException, (
        ('concurrency', (), IcePy._t_bool, False, 0),
        ('backOff', (), IcePy._t_long, False, 0),
        ('type', (), IcePy._t_string, False, 0)
    ))
    WrappedCreateSessionException._ice_type = _M_omero._t_WrappedCreateSessionException

    _M_omero.WrappedCreateSessionException = WrappedCreateSessionException
    del WrappedCreateSessionException

if 'InternalException' not in _M_omero.__dict__:
    _M_omero.InternalException = Ice.createTempClass()
    class InternalException(_M_omero.ServerError):
        """
        Programmer error. Ideally should not be thrown.
        """
        def __init__(self, serverStackTrace='', serverExceptionClass='', message=''):
            _M_omero.ServerError.__init__(self, serverStackTrace, serverExceptionClass, message)

        def __str__(self):
            return IcePy.stringifyException(self)

        __repr__ = __str__

        _ice_name = 'omero::InternalException'

    _M_omero._t_InternalException = IcePy.defineException('::omero::InternalException', InternalException, (), False, _M_omero._t_ServerError, ())
    InternalException._ice_type = _M_omero._t_InternalException

    _M_omero.InternalException = InternalException
    del InternalException

if 'ResourceError' not in _M_omero.__dict__:
    _M_omero.ResourceError = Ice.createTempClass()
    class ResourceError(_M_omero.ServerError):
        """
        Unrecoverable error. The resource being accessed is not available.
        """
        def __init__(self, serverStackTrace='', serverExceptionClass='', message=''):
            _M_omero.ServerError.__init__(self, serverStackTrace, serverExceptionClass, message)

        def __str__(self):
            return IcePy.stringifyException(self)

        __repr__ = __str__

        _ice_name = 'omero::ResourceError'

    _M_omero._t_ResourceError = IcePy.defineException('::omero::ResourceError', ResourceError, (), False, _M_omero._t_ServerError, ())
    ResourceError._ice_type = _M_omero._t_ResourceError

    _M_omero.ResourceError = ResourceError
    del ResourceError

if 'NoProcessorAvailable' not in _M_omero.__dict__:
    _M_omero.NoProcessorAvailable = Ice.createTempClass()
    class NoProcessorAvailable(_M_omero.ResourceError):
        """
        A script cannot be executed because no matching processor
        was found.
        Members:
        processorCount -- Number of processors that responded to the inquiry.
        If 1 or more, then the given script was not acceptable
        (e.g. non-official) and a specialized processor may need
        to be started.
        """
        def __init__(self, serverStackTrace='', serverExceptionClass='', message='', processorCount=0):
            _M_omero.ResourceError.__init__(self, serverStackTrace, serverExceptionClass, message)
            self.processorCount = processorCount

        def __str__(self):
            return IcePy.stringifyException(self)

        __repr__ = __str__

        _ice_name = 'omero::NoProcessorAvailable'

    _M_omero._t_NoProcessorAvailable = IcePy.defineException('::omero::NoProcessorAvailable', NoProcessorAvailable, (), False, _M_omero._t_ResourceError, (('processorCount', (), IcePy._t_int, False, 0),))
    NoProcessorAvailable._ice_type = _M_omero._t_NoProcessorAvailable

    _M_omero.NoProcessorAvailable = NoProcessorAvailable
    del NoProcessorAvailable

if 'ConcurrencyException' not in _M_omero.__dict__:
    _M_omero.ConcurrencyException = Ice.createTempClass()
    class ConcurrencyException(_M_omero.ServerError):
        """
        Recoverable error caused by simultaneous access of some form.
        """
        def __init__(self, serverStackTrace='', serverExceptionClass='', message='', backOff=0):
            _M_omero.ServerError.__init__(self, serverStackTrace, serverExceptionClass, message)
            self.backOff = backOff

        def __str__(self):
            return IcePy.stringifyException(self)

        __repr__ = __str__

        _ice_name = 'omero::ConcurrencyException'

    _M_omero._t_ConcurrencyException = IcePy.defineException('::omero::ConcurrencyException', ConcurrencyException, (), False, _M_omero._t_ServerError, (('backOff', (), IcePy._t_long, False, 0),))
    ConcurrencyException._ice_type = _M_omero._t_ConcurrencyException

    _M_omero.ConcurrencyException = ConcurrencyException
    del ConcurrencyException

if 'ConcurrentModification' not in _M_omero.__dict__:
    _M_omero.ConcurrentModification = Ice.createTempClass()
    class ConcurrentModification(_M_omero.ConcurrencyException):
        """
        Currently unused.
        """
        def __init__(self, serverStackTrace='', serverExceptionClass='', message='', backOff=0):
            _M_omero.ConcurrencyException.__init__(self, serverStackTrace, serverExceptionClass, message, backOff)

        def __str__(self):
            return IcePy.stringifyException(self)

        __repr__ = __str__

        _ice_name = 'omero::ConcurrentModification'

    _M_omero._t_ConcurrentModification = IcePy.defineException('::omero::ConcurrentModification', ConcurrentModification, (), False, _M_omero._t_ConcurrencyException, ())
    ConcurrentModification._ice_type = _M_omero._t_ConcurrentModification

    _M_omero.ConcurrentModification = ConcurrentModification
    del ConcurrentModification

if 'DatabaseBusyException' not in _M_omero.__dict__:
    _M_omero.DatabaseBusyException = Ice.createTempClass()
    class DatabaseBusyException(_M_omero.ConcurrencyException):
        """
        Too many simultaneous database users. This implies that a
        connection to the database could not be acquired, no data
        was saved or modified. Clients may want to wait the given
        backOff period, and retry.
        """
        def __init__(self, serverStackTrace='', serverExceptionClass='', message='', backOff=0):
            _M_omero.ConcurrencyException.__init__(self, serverStackTrace, serverExceptionClass, message, backOff)

        def __str__(self):
            return IcePy.stringifyException(self)

        __repr__ = __str__

        _ice_name = 'omero::DatabaseBusyException'

    _M_omero._t_DatabaseBusyException = IcePy.defineException('::omero::DatabaseBusyException', DatabaseBusyException, (), False, _M_omero._t_ConcurrencyException, ())
    DatabaseBusyException._ice_type = _M_omero._t_DatabaseBusyException

    _M_omero.DatabaseBusyException = DatabaseBusyException
    del DatabaseBusyException

if 'OptimisticLockException' not in _M_omero.__dict__:
    _M_omero.OptimisticLockException = Ice.createTempClass()
    class OptimisticLockException(_M_omero.ConcurrencyException):
        """
        Conflicting changes to the same piece of data.
        """
        def __init__(self, serverStackTrace='', serverExceptionClass='', message='', backOff=0):
            _M_omero.ConcurrencyException.__init__(self, serverStackTrace, serverExceptionClass, message, backOff)

        def __str__(self):
            return IcePy.stringifyException(self)

        __repr__ = __str__

        _ice_name = 'omero::OptimisticLockException'

    _M_omero._t_OptimisticLockException = IcePy.defineException('::omero::OptimisticLockException', OptimisticLockException, (), False, _M_omero._t_ConcurrencyException, ())
    OptimisticLockException._ice_type = _M_omero._t_OptimisticLockException

    _M_omero.OptimisticLockException = OptimisticLockException
    del OptimisticLockException

if 'LockTimeout' not in _M_omero.__dict__:
    _M_omero.LockTimeout = Ice.createTempClass()
    class LockTimeout(_M_omero.ConcurrencyException):
        """
        Lock cannot be acquired and has timed out.
        """
        def __init__(self, serverStackTrace='', serverExceptionClass='', message='', backOff=0, seconds=0):
            _M_omero.ConcurrencyException.__init__(self, serverStackTrace, serverExceptionClass, message, backOff)
            self.seconds = seconds

        def __str__(self):
            return IcePy.stringifyException(self)

        __repr__ = __str__

        _ice_name = 'omero::LockTimeout'

    _M_omero._t_LockTimeout = IcePy.defineException('::omero::LockTimeout', LockTimeout, (), False, _M_omero._t_ConcurrencyException, (('seconds', (), IcePy._t_int, False, 0),))
    LockTimeout._ice_type = _M_omero._t_LockTimeout

    _M_omero.LockTimeout = LockTimeout
    del LockTimeout

if 'TryAgain' not in _M_omero.__dict__:
    _M_omero.TryAgain = Ice.createTempClass()
    class TryAgain(_M_omero.ConcurrencyException):
        """
        Background processing needed before server is ready
        """
        def __init__(self, serverStackTrace='', serverExceptionClass='', message='', backOff=0):
            _M_omero.ConcurrencyException.__init__(self, serverStackTrace, serverExceptionClass, message, backOff)

        def __str__(self):
            return IcePy.stringifyException(self)

        __repr__ = __str__

        _ice_name = 'omero::TryAgain'

    _M_omero._t_TryAgain = IcePy.defineException('::omero::TryAgain', TryAgain, (), False, _M_omero._t_ConcurrencyException, ())
    TryAgain._ice_type = _M_omero._t_TryAgain

    _M_omero.TryAgain = TryAgain
    del TryAgain

if 'MissingPyramidException' not in _M_omero.__dict__:
    _M_omero.MissingPyramidException = Ice.createTempClass()
    class MissingPyramidException(_M_omero.ConcurrencyException):
        def __init__(self, serverStackTrace='', serverExceptionClass='', message='', backOff=0, pixelsID=0):
            _M_omero.ConcurrencyException.__init__(self, serverStackTrace, serverExceptionClass, message, backOff)
            self.pixelsID = pixelsID

        def __str__(self):
            return IcePy.stringifyException(self)

        __repr__ = __str__

        _ice_name = 'omero::MissingPyramidException'

    _M_omero._t_MissingPyramidException = IcePy.defineException('::omero::MissingPyramidException', MissingPyramidException, (), False, _M_omero._t_ConcurrencyException, (('pixelsID', (), IcePy._t_long, False, 0),))
    MissingPyramidException._ice_type = _M_omero._t_MissingPyramidException

    _M_omero.MissingPyramidException = MissingPyramidException
    del MissingPyramidException

if 'ApiUsageException' not in _M_omero.__dict__:
    _M_omero.ApiUsageException = Ice.createTempClass()
    class ApiUsageException(_M_omero.ServerError):
        def __init__(self, serverStackTrace='', serverExceptionClass='', message=''):
            _M_omero.ServerError.__init__(self, serverStackTrace, serverExceptionClass, message)

        def __str__(self):
            return IcePy.stringifyException(self)

        __repr__ = __str__

        _ice_name = 'omero::ApiUsageException'

    _M_omero._t_ApiUsageException = IcePy.defineException('::omero::ApiUsageException', ApiUsageException, (), False, _M_omero._t_ServerError, ())
    ApiUsageException._ice_type = _M_omero._t_ApiUsageException

    _M_omero.ApiUsageException = ApiUsageException
    del ApiUsageException

if 'OverUsageException' not in _M_omero.__dict__:
    _M_omero.OverUsageException = Ice.createTempClass()
    class OverUsageException(_M_omero.ApiUsageException):
        def __init__(self, serverStackTrace='', serverExceptionClass='', message=''):
            _M_omero.ApiUsageException.__init__(self, serverStackTrace, serverExceptionClass, message)

        def __str__(self):
            return IcePy.stringifyException(self)

        __repr__ = __str__

        _ice_name = 'omero::OverUsageException'

    _M_omero._t_OverUsageException = IcePy.defineException('::omero::OverUsageException', OverUsageException, (), False, _M_omero._t_ApiUsageException, ())
    OverUsageException._ice_type = _M_omero._t_OverUsageException

    _M_omero.OverUsageException = OverUsageException
    del OverUsageException

if 'QueryException' not in _M_omero.__dict__:
    _M_omero.QueryException = Ice.createTempClass()
    class QueryException(_M_omero.ApiUsageException):
        def __init__(self, serverStackTrace='', serverExceptionClass='', message=''):
            _M_omero.ApiUsageException.__init__(self, serverStackTrace, serverExceptionClass, message)

        def __str__(self):
            return IcePy.stringifyException(self)

        __repr__ = __str__

        _ice_name = 'omero::QueryException'

    _M_omero._t_QueryException = IcePy.defineException('::omero::QueryException', QueryException, (), False, _M_omero._t_ApiUsageException, ())
    QueryException._ice_type = _M_omero._t_QueryException

    _M_omero.QueryException = QueryException
    del QueryException

if 'ValidationException' not in _M_omero.__dict__:
    _M_omero.ValidationException = Ice.createTempClass()
    class ValidationException(_M_omero.ApiUsageException):
        def __init__(self, serverStackTrace='', serverExceptionClass='', message=''):
            _M_omero.ApiUsageException.__init__(self, serverStackTrace, serverExceptionClass, message)

        def __str__(self):
            return IcePy.stringifyException(self)

        __repr__ = __str__

        _ice_name = 'omero::ValidationException'

    _M_omero._t_ValidationException = IcePy.defineException('::omero::ValidationException', ValidationException, (), False, _M_omero._t_ApiUsageException, ())
    ValidationException._ice_type = _M_omero._t_ValidationException

    _M_omero.ValidationException = ValidationException
    del ValidationException

if 'ChecksumValidationException' not in _M_omero.__dict__:
    _M_omero.ChecksumValidationException = Ice.createTempClass()
    class ChecksumValidationException(_M_omero.ValidationException):
        def __init__(self, serverStackTrace='', serverExceptionClass='', message='', failingChecksums=None):
            _M_omero.ValidationException.__init__(self, serverStackTrace, serverExceptionClass, message)
            self.failingChecksums = failingChecksums

        def __str__(self):
            return IcePy.stringifyException(self)

        __repr__ = __str__

        _ice_name = 'omero::ChecksumValidationException'

    _M_omero._t_ChecksumValidationException = IcePy.defineException('::omero::ChecksumValidationException', ChecksumValidationException, (), False, _M_omero._t_ValidationException, (('failingChecksums', (), _M_omero.api._t_IntStringMap, False, 0),))
    ChecksumValidationException._ice_type = _M_omero._t_ChecksumValidationException

    _M_omero.ChecksumValidationException = ChecksumValidationException
    del ChecksumValidationException

if 'FilePathNamingException' not in _M_omero.__dict__:
    _M_omero.FilePathNamingException = Ice.createTempClass()
    class FilePathNamingException(_M_omero.ValidationException):
        def __init__(self, serverStackTrace='', serverExceptionClass='', message='', illegalFilePath='', illegalCodePoints=None, illegalPrefixes=None, illegalSuffixes=None, illegalNames=None):
            _M_omero.ValidationException.__init__(self, serverStackTrace, serverExceptionClass, message)
            self.illegalFilePath = illegalFilePath
            self.illegalCodePoints = illegalCodePoints
            self.illegalPrefixes = illegalPrefixes
            self.illegalSuffixes = illegalSuffixes
            self.illegalNames = illegalNames

        def __str__(self):
            return IcePy.stringifyException(self)

        __repr__ = __str__

        _ice_name = 'omero::FilePathNamingException'

    _M_omero._t_FilePathNamingException = IcePy.defineException('::omero::FilePathNamingException', FilePathNamingException, (), False, _M_omero._t_ValidationException, (
        ('illegalFilePath', (), IcePy._t_string, False, 0),
        ('illegalCodePoints', (), _M_omero.api._t_IntegerList, False, 0),
        ('illegalPrefixes', (), _M_omero.api._t_StringSet, False, 0),
        ('illegalSuffixes', (), _M_omero.api._t_StringSet, False, 0),
        ('illegalNames', (), _M_omero.api._t_StringSet, False, 0)
    ))
    FilePathNamingException._ice_type = _M_omero._t_FilePathNamingException

    _M_omero.FilePathNamingException = FilePathNamingException
    del FilePathNamingException

if 'SecurityViolation' not in _M_omero.__dict__:
    _M_omero.SecurityViolation = Ice.createTempClass()
    class SecurityViolation(_M_omero.ServerError):
        def __init__(self, serverStackTrace='', serverExceptionClass='', message=''):
            _M_omero.ServerError.__init__(self, serverStackTrace, serverExceptionClass, message)

        def __str__(self):
            return IcePy.stringifyException(self)

        __repr__ = __str__

        _ice_name = 'omero::SecurityViolation'

    _M_omero._t_SecurityViolation = IcePy.defineException('::omero::SecurityViolation', SecurityViolation, (), False, _M_omero._t_ServerError, ())
    SecurityViolation._ice_type = _M_omero._t_SecurityViolation

    _M_omero.SecurityViolation = SecurityViolation
    del SecurityViolation

if 'GroupSecurityViolation' not in _M_omero.__dict__:
    _M_omero.GroupSecurityViolation = Ice.createTempClass()
    class GroupSecurityViolation(_M_omero.SecurityViolation):
        def __init__(self, serverStackTrace='', serverExceptionClass='', message=''):
            _M_omero.SecurityViolation.__init__(self, serverStackTrace, serverExceptionClass, message)

        def __str__(self):
            return IcePy.stringifyException(self)

        __repr__ = __str__

        _ice_name = 'omero::GroupSecurityViolation'

    _M_omero._t_GroupSecurityViolation = IcePy.defineException('::omero::GroupSecurityViolation', GroupSecurityViolation, (), False, _M_omero._t_SecurityViolation, ())
    GroupSecurityViolation._ice_type = _M_omero._t_GroupSecurityViolation

    _M_omero.GroupSecurityViolation = GroupSecurityViolation
    del GroupSecurityViolation

if 'PermissionMismatchGroupSecurityViolation' not in _M_omero.__dict__:
    _M_omero.PermissionMismatchGroupSecurityViolation = Ice.createTempClass()
    class PermissionMismatchGroupSecurityViolation(_M_omero.SecurityViolation):
        def __init__(self, serverStackTrace='', serverExceptionClass='', message=''):
            _M_omero.SecurityViolation.__init__(self, serverStackTrace, serverExceptionClass, message)

        def __str__(self):
            return IcePy.stringifyException(self)

        __repr__ = __str__

        _ice_name = 'omero::PermissionMismatchGroupSecurityViolation'

    _M_omero._t_PermissionMismatchGroupSecurityViolation = IcePy.defineException('::omero::PermissionMismatchGroupSecurityViolation', PermissionMismatchGroupSecurityViolation, (), False, _M_omero._t_SecurityViolation, ())
    PermissionMismatchGroupSecurityViolation._ice_type = _M_omero._t_PermissionMismatchGroupSecurityViolation

    _M_omero.PermissionMismatchGroupSecurityViolation = PermissionMismatchGroupSecurityViolation
    del PermissionMismatchGroupSecurityViolation

if 'ReadOnlyGroupSecurityViolation' not in _M_omero.__dict__:
    _M_omero.ReadOnlyGroupSecurityViolation = Ice.createTempClass()
    class ReadOnlyGroupSecurityViolation(_M_omero.SecurityViolation):
        def __init__(self, serverStackTrace='', serverExceptionClass='', message=''):
            _M_omero.SecurityViolation.__init__(self, serverStackTrace, serverExceptionClass, message)

        def __str__(self):
            return IcePy.stringifyException(self)

        __repr__ = __str__

        _ice_name = 'omero::ReadOnlyGroupSecurityViolation'

    _M_omero._t_ReadOnlyGroupSecurityViolation = IcePy.defineException('::omero::ReadOnlyGroupSecurityViolation', ReadOnlyGroupSecurityViolation, (), False, _M_omero._t_SecurityViolation, ())
    ReadOnlyGroupSecurityViolation._ice_type = _M_omero._t_ReadOnlyGroupSecurityViolation

    _M_omero.ReadOnlyGroupSecurityViolation = ReadOnlyGroupSecurityViolation
    del ReadOnlyGroupSecurityViolation

if 'OmeroFSError' not in _M_omero.__dict__:
    _M_omero.OmeroFSError = Ice.createTempClass()
    class OmeroFSError(_M_omero.ServerError):
        """
        OmeroFSError
        Just one catch-all UserException for the present. It could be
        subclassed to provide a finer grained level if necessary.
        It should be fitted into or subsumed within the above hierarchy
        """
        def __init__(self, serverStackTrace='', serverExceptionClass='', message='', reason=''):
            _M_omero.ServerError.__init__(self, serverStackTrace, serverExceptionClass, message)
            self.reason = reason

        def __str__(self):
            return IcePy.stringifyException(self)

        __repr__ = __str__

        _ice_name = 'omero::OmeroFSError'

    _M_omero._t_OmeroFSError = IcePy.defineException('::omero::OmeroFSError', OmeroFSError, (), False, _M_omero._t_ServerError, (('reason', (), IcePy._t_string, False, 0),))
    OmeroFSError._ice_type = _M_omero._t_OmeroFSError

    _M_omero.OmeroFSError = OmeroFSError
    del OmeroFSError

# End of module omero



# -*- coding: utf-8 -*-
# **********************************************************************
#
# Copyright (c) 2003-2017 ZeroC, Inc. All rights reserved.
#
# This copy of Ice is licensed to you under the terms described in the
# ICE_LICENSE file included in this distribution.
#
# **********************************************************************
#
# Ice version 3.6.4
#
# <auto-generated>
#
# Generated from file `RawFileStore.ice'
#
# Warning: do not edit this file.
#
# </auto-generated>
#

from sys import version_info as _version_info_
import Ice, IcePy
import omero_ModelF_ice
import omero_ServicesF_ice
import omero_Collections_ice

# Included module omero
_M_omero = Ice.openModule('omero')

# Included module omero.model
_M_omero.model = Ice.openModule('omero.model')

# Included module Ice
_M_Ice = Ice.openModule('Ice')

# Included module Glacier2
_M_Glacier2 = Ice.openModule('Glacier2')

# Included module omero.sys
_M_omero.sys = Ice.openModule('omero.sys')

# Included module omero.api
_M_omero.api = Ice.openModule('omero.api')

# Included module omero.grid
_M_omero.grid = Ice.openModule('omero.grid')

# Start of module omero
__name__ = 'omero'

# Start of module omero.api
__name__ = 'omero.api'

if 'RawFileStore' not in _M_omero.api.__dict__:
    _M_omero.api.RawFileStore = Ice.createTempClass()
    class RawFileStore(_M_omero.api.StatefulServiceInterface):
        """
        Raw file gateway which provides access to the OMERO file repository.
        Note: methods on this service are protected by a DOWNLOAD
        restriction.
        """
        def __init__(self):
            if Ice.getType(self) == _M_omero.api.RawFileStore:
                raise RuntimeError('omero.api.RawFileStore is an abstract class')

        def ice_ids(self, current=None):
            return ('::Ice::Object', '::omero::api::RawFileStore', '::omero::api::ServiceInterface', '::omero::api::StatefulServiceInterface')

        def ice_id(self, current=None):
            return '::omero::api::RawFileStore'

        def ice_staticId():
            return '::omero::api::RawFileStore'
        ice_staticId = staticmethod(ice_staticId)

        def setFileId_async(self, _cb, fileId, current=None):
            """
            This method manages the state of the service. This method
            will throw a omero.SecurityViolation if for the
            current user context either the file is not readable or a
            {@code omero.constants.permissions.BINARYACCESS} restriction is
            in place.
            Arguments:
            _cb -- The asynchronous callback object.
            fileId -- 
            current -- The Current object for the invocation.
            """
            pass

        def getFileId_async(self, _cb, current=None):
            """
            Returns the current file id or null if none has been set.
            Arguments:
            _cb -- The asynchronous callback object.
            current -- The Current object for the invocation.
            """
            pass

        def read_async(self, _cb, position, length, current=None):
            """
            Reads length bytes of data at the
            position from the raw file into an array of
            bytes.
            Arguments:
            _cb -- The asynchronous callback object.
            position -- 
            length -- 
            current -- The Current object for the invocation.
            """
            pass

        def size_async(self, _cb, current=None):
            """
            Returns the size of the file on disk (not as stored in the
            database since that value will only be updated on
            {@code save}. If the file has not yet been written to, and
            therefore does not exist, a omero.ResourceError
            will be thrown.
            Arguments:
            _cb -- The asynchronous callback object.
            current -- The Current object for the invocation.
            """
            pass

        def truncate_async(self, _cb, length, current=None):
            """
            Limits the size of a file to the given length. If the file
            is already shorter than length, no action is taken in which
            case false is returned.
            Arguments:
            _cb -- The asynchronous callback object.
            length -- 
            current -- The Current object for the invocation.
            """
            pass

        def write_async(self, _cb, buf, position, length, current=None):
            """
            Writes length bytes of data from the specified
            buf byte array starting at at
            position to the raw file.
            Arguments:
            _cb -- The asynchronous callback object.
            buf -- 
            position -- 
            length -- 
            current -- The Current object for the invocation.
            """
            pass

        def exists_async(self, _cb, current=None):
            """
            Checks to see if a raw file exists with the file ID that
            the service was initialized with.
            Arguments:
            _cb -- The asynchronous callback object.
            current -- The Current object for the invocation.
            Throws:
            ResourceError -- if there is a problem accessing the file due to permissions errors within the repository or any other I/O error.
            """
            pass

        def save_async(self, _cb, current=None):
            """
            Saves the omero.model.OriginalFile associated with
            the service if it has been modified. The returned valued
            should replace all instances of the
            omero.model.OriginalFile in the client.
            If save has not been called, omero.api.RawFileStore
            instances will save the omero.model.OriginalFile
            object associated with it on {@code close}.
            See also ticket 1651
            and ticket 2161.
            Arguments:
            _cb -- The asynchronous callback object.
            current -- The Current object for the invocation.
            """
            pass

        def __str__(self):
            return IcePy.stringify(self, _M_omero.api._t_RawFileStore)

        __repr__ = __str__

    _M_omero.api.RawFileStorePrx = Ice.createTempClass()
    class RawFileStorePrx(_M_omero.api.StatefulServiceInterfacePrx):

        """
        This method manages the state of the service. This method
        will throw a omero.SecurityViolation if for the
        current user context either the file is not readable or a
        {@code omero.constants.permissions.BINARYACCESS} restriction is
        in place.
        Arguments:
        fileId -- 
        _ctx -- The request context for the invocation.
        """
        def setFileId(self, fileId, _ctx=None):
            return _M_omero.api.RawFileStore._op_setFileId.invoke(self, ((fileId, ), _ctx))

        """
        This method manages the state of the service. This method
        will throw a omero.SecurityViolation if for the
        current user context either the file is not readable or a
        {@code omero.constants.permissions.BINARYACCESS} restriction is
        in place.
        Arguments:
        fileId -- 
        _response -- The asynchronous response callback.
        _ex -- The asynchronous exception callback.
        _sent -- The asynchronous sent callback.
        _ctx -- The request context for the invocation.
        Returns: An asynchronous result object for the invocation.
        """
        def begin_setFileId(self, fileId, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.api.RawFileStore._op_setFileId.begin(self, ((fileId, ), _response, _ex, _sent, _ctx))

        """
        This method manages the state of the service. This method
        will throw a omero.SecurityViolation if for the
        current user context either the file is not readable or a
        {@code omero.constants.permissions.BINARYACCESS} restriction is
        in place.
        Arguments:
        fileId -- 
        """
        def end_setFileId(self, _r):
            return _M_omero.api.RawFileStore._op_setFileId.end(self, _r)

        """
        Returns the current file id or null if none has been set.
        Arguments:
        _ctx -- The request context for the invocation.
        """
        def getFileId(self, _ctx=None):
            return _M_omero.api.RawFileStore._op_getFileId.invoke(self, ((), _ctx))

        """
        Returns the current file id or null if none has been set.
        Arguments:
        _response -- The asynchronous response callback.
        _ex -- The asynchronous exception callback.
        _sent -- The asynchronous sent callback.
        _ctx -- The request context for the invocation.
        Returns: An asynchronous result object for the invocation.
        """
        def begin_getFileId(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.api.RawFileStore._op_getFileId.begin(self, ((), _response, _ex, _sent, _ctx))

        """
        Returns the current file id or null if none has been set.
        Arguments:
        """
        def end_getFileId(self, _r):
            return _M_omero.api.RawFileStore._op_getFileId.end(self, _r)

        """
        Reads length bytes of data at the
        position from the raw file into an array of
        bytes.
        Arguments:
        position -- 
        length -- 
        _ctx -- The request context for the invocation.
        """
        def read(self, position, length, _ctx=None):
            return _M_omero.api.RawFileStore._op_read.invoke(self, ((position, length), _ctx))

        """
        Reads length bytes of data at the
        position from the raw file into an array of
        bytes.
        Arguments:
        position -- 
        length -- 
        _response -- The asynchronous response callback.
        _ex -- The asynchronous exception callback.
        _sent -- The asynchronous sent callback.
        _ctx -- The request context for the invocation.
        Returns: An asynchronous result object for the invocation.
        """
        def begin_read(self, position, length, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.api.RawFileStore._op_read.begin(self, ((position, length), _response, _ex, _sent, _ctx))

        """
        Reads length bytes of data at the
        position from the raw file into an array of
        bytes.
        Arguments:
        position -- 
        length -- 
        """
        def end_read(self, _r):
            return _M_omero.api.RawFileStore._op_read.end(self, _r)

        """
        Returns the size of the file on disk (not as stored in the
        database since that value will only be updated on
        {@code save}. If the file has not yet been written to, and
        therefore does not exist, a omero.ResourceError
        will be thrown.
        Arguments:
        _ctx -- The request context for the invocation.
        """
        def size(self, _ctx=None):
            return _M_omero.api.RawFileStore._op_size.invoke(self, ((), _ctx))

        """
        Returns the size of the file on disk (not as stored in the
        database since that value will only be updated on
        {@code save}. If the file has not yet been written to, and
        therefore does not exist, a omero.ResourceError
        will be thrown.
        Arguments:
        _response -- The asynchronous response callback.
        _ex -- The asynchronous exception callback.
        _sent -- The asynchronous sent callback.
        _ctx -- The request context for the invocation.
        Returns: An asynchronous result object for the invocation.
        """
        def begin_size(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.api.RawFileStore._op_size.begin(self, ((), _response, _ex, _sent, _ctx))

        """
        Returns the size of the file on disk (not as stored in the
        database since that value will only be updated on
        {@code save}. If the file has not yet been written to, and
        therefore does not exist, a omero.ResourceError
        will be thrown.
        Arguments:
        """
        def end_size(self, _r):
            return _M_omero.api.RawFileStore._op_size.end(self, _r)

        """
        Limits the size of a file to the given length. If the file
        is already shorter than length, no action is taken in which
        case false is returned.
        Arguments:
        length -- 
        _ctx -- The request context for the invocation.
        """
        def truncate(self, length, _ctx=None):
            return _M_omero.api.RawFileStore._op_truncate.invoke(self, ((length, ), _ctx))

        """
        Limits the size of a file to the given length. If the file
        is already shorter than length, no action is taken in which
        case false is returned.
        Arguments:
        length -- 
        _response -- The asynchronous response callback.
        _ex -- The asynchronous exception callback.
        _sent -- The asynchronous sent callback.
        _ctx -- The request context for the invocation.
        Returns: An asynchronous result object for the invocation.
        """
        def begin_truncate(self, length, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.api.RawFileStore._op_truncate.begin(self, ((length, ), _response, _ex, _sent, _ctx))

        """
        Limits the size of a file to the given length. If the file
        is already shorter than length, no action is taken in which
        case false is returned.
        Arguments:
        length -- 
        """
        def end_truncate(self, _r):
            return _M_omero.api.RawFileStore._op_truncate.end(self, _r)

        """
        Writes length bytes of data from the specified
        buf byte array starting at at
        position to the raw file.
        Arguments:
        buf -- 
        position -- 
        length -- 
        _ctx -- The request context for the invocation.
        """
        def write(self, buf, position, length, _ctx=None):
            return _M_omero.api.RawFileStore._op_write.invoke(self, ((buf, position, length), _ctx))

        """
        Writes length bytes of data from the specified
        buf byte array starting at at
        position to the raw file.
        Arguments:
        buf -- 
        position -- 
        length -- 
        _response -- The asynchronous response callback.
        _ex -- The asynchronous exception callback.
        _sent -- The asynchronous sent callback.
        _ctx -- The request context for the invocation.
        Returns: An asynchronous result object for the invocation.
        """
        def begin_write(self, buf, position, length, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.api.RawFileStore._op_write.begin(self, ((buf, position, length), _response, _ex, _sent, _ctx))

        """
        Writes length bytes of data from the specified
        buf byte array starting at at
        position to the raw file.
        Arguments:
        buf -- 
        position -- 
        length -- 
        """
        def end_write(self, _r):
            return _M_omero.api.RawFileStore._op_write.end(self, _r)

        """
        Checks to see if a raw file exists with the file ID that
        the service was initialized with.
        Arguments:
        _ctx -- The request context for the invocation.
        Returns: true if there is an accessible file within the original file repository with the correct ID. Otherwise false.
        Throws:
        ResourceError -- if there is a problem accessing the file due to permissions errors within the repository or any other I/O error.
        """
        def exists(self, _ctx=None):
            return _M_omero.api.RawFileStore._op_exists.invoke(self, ((), _ctx))

        """
        Checks to see if a raw file exists with the file ID that
        the service was initialized with.
        Arguments:
        _response -- The asynchronous response callback.
        _ex -- The asynchronous exception callback.
        _sent -- The asynchronous sent callback.
        _ctx -- The request context for the invocation.
        Returns: An asynchronous result object for the invocation.
        """
        def begin_exists(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.api.RawFileStore._op_exists.begin(self, ((), _response, _ex, _sent, _ctx))

        """
        Checks to see if a raw file exists with the file ID that
        the service was initialized with.
        Arguments:
        Returns: true if there is an accessible file within the original file repository with the correct ID. Otherwise false.
        Throws:
        ResourceError -- if there is a problem accessing the file due to permissions errors within the repository or any other I/O error.
        """
        def end_exists(self, _r):
            return _M_omero.api.RawFileStore._op_exists.end(self, _r)

        """
        Saves the omero.model.OriginalFile associated with
        the service if it has been modified. The returned valued
        should replace all instances of the
        omero.model.OriginalFile in the client.
        If save has not been called, omero.api.RawFileStore
        instances will save the omero.model.OriginalFile
        object associated with it on {@code close}.
        See also ticket 1651
        and ticket 2161.
        Arguments:
        _ctx -- The request context for the invocation.
        """
        def save(self, _ctx=None):
            return _M_omero.api.RawFileStore._op_save.invoke(self, ((), _ctx))

        """
        Saves the omero.model.OriginalFile associated with
        the service if it has been modified. The returned valued
        should replace all instances of the
        omero.model.OriginalFile in the client.
        If save has not been called, omero.api.RawFileStore
        instances will save the omero.model.OriginalFile
        object associated with it on {@code close}.
        See also ticket 1651
        and ticket 2161.
        Arguments:
        _response -- The asynchronous response callback.
        _ex -- The asynchronous exception callback.
        _sent -- The asynchronous sent callback.
        _ctx -- The request context for the invocation.
        Returns: An asynchronous result object for the invocation.
        """
        def begin_save(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.api.RawFileStore._op_save.begin(self, ((), _response, _ex, _sent, _ctx))

        """
        Saves the omero.model.OriginalFile associated with
        the service if it has been modified. The returned valued
        should replace all instances of the
        omero.model.OriginalFile in the client.
        If save has not been called, omero.api.RawFileStore
        instances will save the omero.model.OriginalFile
        object associated with it on {@code close}.
        See also ticket 1651
        and ticket 2161.
        Arguments:
        """
        def end_save(self, _r):
            return _M_omero.api.RawFileStore._op_save.end(self, _r)

        def checkedCast(proxy, facetOrCtx=None, _ctx=None):
            return _M_omero.api.RawFileStorePrx.ice_checkedCast(proxy, '::omero::api::RawFileStore', facetOrCtx, _ctx)
        checkedCast = staticmethod(checkedCast)

        def uncheckedCast(proxy, facet=None):
            return _M_omero.api.RawFileStorePrx.ice_uncheckedCast(proxy, facet)
        uncheckedCast = staticmethod(uncheckedCast)

        def ice_staticId():
            return '::omero::api::RawFileStore'
        ice_staticId = staticmethod(ice_staticId)

    _M_omero.api._t_RawFileStorePrx = IcePy.defineProxy('::omero::api::RawFileStore', RawFileStorePrx)

    _M_omero.api._t_RawFileStore = IcePy.defineClass('::omero::api::RawFileStore', RawFileStore, -1, (), True, False, None, (_M_omero.api._t_StatefulServiceInterface,), ())
    RawFileStore._ice_type = _M_omero.api._t_RawFileStore

    RawFileStore._op_setFileId = IcePy.Operation('setFileId', Ice.OperationMode.Normal, Ice.OperationMode.Normal, True, None, (), (((), IcePy._t_long, False, 0),), (), None, (_M_omero._t_ServerError,))
    RawFileStore._op_getFileId = IcePy.Operation('getFileId', Ice.OperationMode.Idempotent, Ice.OperationMode.Idempotent, True, None, (), (), (), ((), _M_omero._t_RLong, False, 0), (_M_omero._t_ServerError,))
    RawFileStore._op_read = IcePy.Operation('read', Ice.OperationMode.Idempotent, Ice.OperationMode.Idempotent, True, None, (), (((), IcePy._t_long, False, 0), ((), IcePy._t_int, False, 0)), (), ((), _M_Ice._t_ByteSeq, False, 0), (_M_omero._t_ServerError,))
    RawFileStore._op_size = IcePy.Operation('size', Ice.OperationMode.Idempotent, Ice.OperationMode.Idempotent, True, None, (), (), (), ((), IcePy._t_long, False, 0), (_M_omero._t_ServerError,))
    RawFileStore._op_truncate = IcePy.Operation('truncate', Ice.OperationMode.Idempotent, Ice.OperationMode.Idempotent, True, None, (), (((), IcePy._t_long, False, 0),), (), ((), IcePy._t_bool, False, 0), (_M_omero._t_ServerError,))
    RawFileStore._op_write = IcePy.Operation('write', Ice.OperationMode.Idempotent, Ice.OperationMode.Idempotent, True, None, (), (((), _M_Ice._t_ByteSeq, False, 0), ((), IcePy._t_long, False, 0), ((), IcePy._t_int, False, 0)), (), None, (_M_omero._t_ServerError,))
    RawFileStore._op_exists = IcePy.Operation('exists', Ice.OperationMode.Idempotent, Ice.OperationMode.Idempotent, True, None, (), (), (), ((), IcePy._t_bool, False, 0), (_M_omero._t_ServerError,))
    RawFileStore._op_save = IcePy.Operation('save', Ice.OperationMode.Idempotent, Ice.OperationMode.Idempotent, True, None, (), (), (), ((), _M_omero.model._t_OriginalFile, False, 0), (_M_omero._t_ServerError,))

    _M_omero.api.RawFileStore = RawFileStore
    del RawFileStore

    _M_omero.api.RawFileStorePrx = RawFileStorePrx
    del RawFileStorePrx

# End of module omero.api

__name__ = 'omero'

# End of module omero



# -*- coding: utf-8 -*-
# **********************************************************************
#
# Copyright (c) 2003-2017 ZeroC, Inc. All rights reserved.
#
# This copy of Ice is licensed to you under the terms described in the
# ICE_LICENSE file included in this distribution.
#
# **********************************************************************
#
# Ice version 3.6.4
#
# <auto-generated>
#
# Generated from file `GenericExcitationSource.ice'
#
# Warning: do not edit this file.
#
# </auto-generated>
#

from sys import version_info as _version_info_
import Ice, IcePy
import omero_model_IObject_ice
import omero_RTypes_ice
import omero_model_RTypes_ice
import omero_System_ice
import omero_Collections_ice
import omero_model_LightSource_ice

# Included module omero
_M_omero = Ice.openModule('omero')

# Included module omero.model
_M_omero.model = Ice.openModule('omero.model')

# Included module Ice
_M_Ice = Ice.openModule('Ice')

# Included module omero.sys
_M_omero.sys = Ice.openModule('omero.sys')

# Included module omero.api
_M_omero.api = Ice.openModule('omero.api')

# Start of module omero
__name__ = 'omero'

# Start of module omero.model
__name__ = 'omero.model'

if 'Power' not in _M_omero.model.__dict__:
    _M_omero.model._t_Power = IcePy.declareClass('::omero::model::Power')
    _M_omero.model._t_PowerPrx = IcePy.declareProxy('::omero::model::Power')

if 'Instrument' not in _M_omero.model.__dict__:
    _M_omero.model._t_Instrument = IcePy.declareClass('::omero::model::Instrument')
    _M_omero.model._t_InstrumentPrx = IcePy.declareProxy('::omero::model::Instrument')

if 'LightSourceAnnotationLink' not in _M_omero.model.__dict__:
    _M_omero.model._t_LightSourceAnnotationLink = IcePy.declareClass('::omero::model::LightSourceAnnotationLink')
    _M_omero.model._t_LightSourceAnnotationLinkPrx = IcePy.declareProxy('::omero::model::LightSourceAnnotationLink')

if 'Annotation' not in _M_omero.model.__dict__:
    _M_omero.model._t_Annotation = IcePy.declareClass('::omero::model::Annotation')
    _M_omero.model._t_AnnotationPrx = IcePy.declareProxy('::omero::model::Annotation')

if 'Details' not in _M_omero.model.__dict__:
    _M_omero.model._t_Details = IcePy.declareClass('::omero::model::Details')
    _M_omero.model._t_DetailsPrx = IcePy.declareProxy('::omero::model::Details')

if 'GenericExcitationSource' not in _M_omero.model.__dict__:
    _M_omero.model.GenericExcitationSource = Ice.createTempClass()
    class GenericExcitationSource(_M_omero.model.LightSource):
        def __init__(self, _id=None, _details=None, _loaded=False, _version=None, _manufacturer=None, _model=None, _power=None, _lotNumber=None, _serialNumber=None, _instrument=None, _annotationLinksSeq=None, _annotationLinksLoaded=False, _annotationLinksCountPerOwner=None, _map=None):
            if Ice.getType(self) == _M_omero.model.GenericExcitationSource:
                raise RuntimeError('omero.model.GenericExcitationSource is an abstract class')
            _M_omero.model.LightSource.__init__(self, _id, _details, _loaded, _version, _manufacturer, _model, _power, _lotNumber, _serialNumber, _instrument, _annotationLinksSeq, _annotationLinksLoaded, _annotationLinksCountPerOwner)
            self._map = _map

        def ice_ids(self, current=None):
            return ('::Ice::Object', '::omero::model::GenericExcitationSource', '::omero::model::IObject', '::omero::model::LightSource')

        def ice_id(self, current=None):
            return '::omero::model::GenericExcitationSource'

        def ice_staticId():
            return '::omero::model::GenericExcitationSource'
        ice_staticId = staticmethod(ice_staticId)

        def getMapAsMap(self, current=None):
            pass

        def getMap(self, current=None):
            pass

        def setMap(self, theMap, current=None):
            pass

        def __str__(self):
            return IcePy.stringify(self, _M_omero.model._t_GenericExcitationSource)

        __repr__ = __str__

    _M_omero.model.GenericExcitationSourcePrx = Ice.createTempClass()
    class GenericExcitationSourcePrx(_M_omero.model.LightSourcePrx):

        def getMapAsMap(self, _ctx=None):
            return _M_omero.model.GenericExcitationSource._op_getMapAsMap.invoke(self, ((), _ctx))

        def begin_getMapAsMap(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.GenericExcitationSource._op_getMapAsMap.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_getMapAsMap(self, _r):
            return _M_omero.model.GenericExcitationSource._op_getMapAsMap.end(self, _r)

        def getMap(self, _ctx=None):
            return _M_omero.model.GenericExcitationSource._op_getMap.invoke(self, ((), _ctx))

        def begin_getMap(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.GenericExcitationSource._op_getMap.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_getMap(self, _r):
            return _M_omero.model.GenericExcitationSource._op_getMap.end(self, _r)

        def setMap(self, theMap, _ctx=None):
            return _M_omero.model.GenericExcitationSource._op_setMap.invoke(self, ((theMap, ), _ctx))

        def begin_setMap(self, theMap, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.GenericExcitationSource._op_setMap.begin(self, ((theMap, ), _response, _ex, _sent, _ctx))

        def end_setMap(self, _r):
            return _M_omero.model.GenericExcitationSource._op_setMap.end(self, _r)

        def checkedCast(proxy, facetOrCtx=None, _ctx=None):
            return _M_omero.model.GenericExcitationSourcePrx.ice_checkedCast(proxy, '::omero::model::GenericExcitationSource', facetOrCtx, _ctx)
        checkedCast = staticmethod(checkedCast)

        def uncheckedCast(proxy, facet=None):
            return _M_omero.model.GenericExcitationSourcePrx.ice_uncheckedCast(proxy, facet)
        uncheckedCast = staticmethod(uncheckedCast)

        def ice_staticId():
            return '::omero::model::GenericExcitationSource'
        ice_staticId = staticmethod(ice_staticId)

    _M_omero.model._t_GenericExcitationSourcePrx = IcePy.defineProxy('::omero::model::GenericExcitationSource', GenericExcitationSourcePrx)

    _M_omero.model._t_GenericExcitationSource = IcePy.declareClass('::omero::model::GenericExcitationSource')

    _M_omero.model._t_GenericExcitationSource = IcePy.defineClass('::omero::model::GenericExcitationSource', GenericExcitationSource, -1, (), True, False, _M_omero.model._t_LightSource, (), (('_map', (), _M_omero.api._t_NamedValueList, False, 0),))
    GenericExcitationSource._ice_type = _M_omero.model._t_GenericExcitationSource

    GenericExcitationSource._op_getMapAsMap = IcePy.Operation('getMapAsMap', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero.api._t_StringStringMap, False, 0), ())
    GenericExcitationSource._op_getMap = IcePy.Operation('getMap', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero.api._t_NamedValueList, False, 0), ())
    GenericExcitationSource._op_setMap = IcePy.Operation('setMap', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.api._t_NamedValueList, False, 0),), (), None, ())

    _M_omero.model.GenericExcitationSource = GenericExcitationSource
    del GenericExcitationSource

    _M_omero.model.GenericExcitationSourcePrx = GenericExcitationSourcePrx
    del GenericExcitationSourcePrx

# End of module omero.model

__name__ = 'omero'

# End of module omero



#!/usr/bin/env python
# -*- coding: utf-8 -*-

# Copyright 2008 Glencoe Software, Inc. All rights reserved.
# Use is subject to license terms supplied in LICENSE.txt
#

import Ice
import omero
from omero.rtypes import rint, rbool, rtime, rlist, rstring, rlong

_omero = Ice.openModule("omero")
_omero_sys = Ice.openModule("omero.sys")
__name__ = "omero.sys"


class ParametersI(omero.sys.Parameters):
    """
    Helper subclass of omero.sys.Parameters for simplifying method
    parameter creation.
    """

    def __init__(self, parammap=None):
        """
        If no argument is provided, creates an instance to prevent later
        NoneType exceptions. To save memory, it is possible to pass None
        as the first argument.

        In order to prevent a single dict being referenced by several
        instances of ParametersI a new dict is created if an empty one is
        passed in either implicitly or explicitly.

        Uses (and does not copy) the given dict as the named parameter
        store in this instance. Be careful if either null is passed in
        or if this instance is being used in a multi-threaded environment.
        No synchronization takes place.
        """
        if parammap is None or len(parammap) == 0:
            self.map = {}
        else:
            self.map = parammap
        self.theFilter = None
        self.theOptions = None

    def _rt(self, arg, rt):
        """
        if arg is None, return None, otherwise use the
        rt callable to wrap the argument.
        """
        if arg is None:
            return None
        else:
            return rt(arg)

    # Parameters.theFilter.limit & offset
    # ====================================================================

    def noPage(self):
        """
        Nulls both the Filter.limit and Filter.offset values.
        """
        if self.theFilter:
            self.theFilter.limit = None
            self.theFilter.offset = None
        return self

    def page(self, offset, limit):
        """
        Sets both the Filter.limit and Filter.offset values by
        wrapping the arguments in omero.RInts if necessary.
        """
        if not self.theFilter:
            self.theFilter = omero.sys.Filter()
        self.theFilter.limit = self._rt(limit, rint)
        self.theFilter.offset = self._rt(offset, rint)
        return self

    def isPagination(self):
        """
        Returns True if the filter contains a limit OR an offset,
        False otherwise.
        """
        if self.theFilter:
            return None != self.theFilter.limit or \
                None != self.theFilter.offset
        return False

    def getOffset(self):
        """
        Returns the value of the offset parameter.
        """
        if self.theFilter:
            return self.theFilter.offset
        return None

    def getLimit(self):
        """
        Returns the value of the limit parameter.
        """
        if self.theFilter:
            return self.theFilter.limit
        return None

    def unique(self):
        if not self.theFilter:
            self.theFilter = omero.sys.Filter()
        self.theFilter.unique = rbool(True)
        return self

    def noUnique(self):
        if not self.theFilter:
            self.theFilter = omero.sys.Filter()
        self.theFilter.unique = rbool(False)
        return self

    def getUnique(self):
        if self.theFilter:
            return self.theFilter.unique
        return None

    # Parameters.theFilter.ownerId & groupId
    # ====================================================================

    def exp(self, i):
        """
        Sets the value of the <code>experimenter</code> parameter.
        """
        if not self.theFilter:
            self.theFilter = omero.sys.Filter()
        self.theFilter.ownerId = self._rt(i, rlong)
        return self

    def allExps(self):
        """
        Removes the <code>experimenter</code> parameter from the map.
        """
        if self.theFilter:
            self.theFilter.ownerId = None
        return self

    def isExperimenter(self):
        """
        Returns <code>true</code> if the filter contains and
        <code>ownerId</code> parameter, <code>false</code> otherwise.
        """
        if self.theFilter:
            return None != self.theFilter.ownerId
        return False

    def getExperimenter(self):
        """
        Returns the value of the <code>experimenter</code> parameter.
        """
        if self.theFilter:
            return self.theFilter.ownerId
        return None

    def grp(self, i):
        """
        Sets the value of the <code>group</code> parameter.
        """
        if not self.theFilter:
            self.theFilter = omero.sys.Filter()
        self.theFilter.groupId = self._rt(i, rlong)
        return self

    def allGrps(self):
        """
        Removes the <code>group</code> parameter from the map.
        """
        if self.theFilter:
            self.theFilter.groupId = None
        return self

    def isGroup(self):
        """
        Returns <code>true</code> if the filter contains an
        <code>groupId</code>, <code>false</code> otherwise.
        """
        if self.theFilter:
            return None != self.theFilter.groupId
        return False

    def getGroup(self):
        """
        Returns the value of the <code>group</code> parameter.
        """
        if self.theFilter:
            return self.theFilter.groupId
        return None

    # ~ Parameters.theFilter.startTime, endTime
    # ====================================================================

    def startTime(self, startTime):
        """
        Sets the value of the <code>start time</code> parameter.
        """
        if not self.theFilter:
            self.theFilter = omero.sys.Filter()
            self.theFilter.startTime = self._rt(startTime, rtime)
        return self

    def endTime(self, endTime):
        """
        Sets the value of the <code>end time</code> parameter.
        """
        if not self.theFilter:
            self.theFilter = omero.sys.Filter()
        self.theFilter.endTime = self._rt(endTime, rtime)
        return self

    def allTimes(self):
        """
        Removes the time parameters from the map.
        """
        if self.theFilter:
            self.theFilter.startTime = None
            self.theFilter.endTime = None
        return self

    def isStartTime(self):
        """
        Returns <code>true</code> if the map contains the
        <code>startTime</code> parameter, <code>false</code> otherwise.
        """
        if self.theFilter:
            return None != self.theFilter.startTime
        return False

    def getStartTime(self):
        """
        Returns the value of the <code>start time</code> parameter.
        """
        if self.theFilter:
            return self.theFilter.startTime
        return None

    def isEndTime(self):
        """
        Returns <code>true</code> if the map contains the <code>end time</code>
        parameter, <code>false</code> otherwise.
        """
        if self.theFilter:
            return None != self.theFilter.endTime
        return False

    def getEndTime(self):
        """
        Returns the value of the <code>end time</code> parameter.
        """
        if self.theFilter:
            return self.theFilter.endTime
        return None

    # ~ Parameters.theOption.leaves, orphan, acquisitionData, cacheable
    # ====================================================================

    def leaves(self):
        if not self.theOptions:
            self.theOptions = omero.sys.Options()
        self.theOptions.leaves = rbool(True)
        return self

    def noLeaves(self):
        if not self.theOptions:
            self.theOptions = omero.sys.Options()
        self.theOptions.leaves = rbool(False)
        return self

    def getLeaves(self):
        if self.theOptions:
            return self.theOptions.leaves
        return None

    def orphan(self):
        if not self.theOptions:
            self.theOptions = omero.sys.Options()
        self.theOptions.orphan = rbool(True)
        return self

    def noOrphan(self):
        if not self.theOptions:
            self.theOptions = omero.sys.Options()
        self.theOptions.orphan = rbool(False)
        return self

    def getOrphan(self):
        if self.theOptions:
            return self.theOptions.orphan
        return None

    def acquisitionData(self):
        if not self.theOptions:
            self.theOptions = omero.sys.Options()
        self.theOptions.acquisitionData = rbool(True)
        return self

    def noAcquisitionData(self):
        if not self.theOptions:
            self.theOptions = omero.sys.Options()
        self.theOptions.acquisitionData = rbool(False)
        return self

    def getAcquisitionData(self):
        if self.theOptions:
            return self.theOptions.acquisitionData
        return None

    def cache(self):
        if not self.theOptions:
            self.theOptions = omero.sys.Options()
        self.theOptions.cache = rbool(True)
        return self

    def noCache(self):
        if not self.theOptions:
            self.theOptions = omero.sys.Options()
        self.theOptions.cache = rbool(False)
        return self

    def getCache(self):
        if self.theOptions:
            return self.theOptions.cache
        return None

    # Parameters.map
    # ====================================================================

    def add(self, name, rtype):
        self.map[name] = rtype
        return self

    def addId(self, id):
        self.addLong("id", rlong(id))
        return self

    def addIds(self, longs):
        self.addLongs("ids", longs)
        return self

    def addLong(self, name, longValue):
        self.add(name, rlong(longValue))
        return self

    def addLongs(self, name, longs):
        rlongs = rlist([])
        for l in longs:
            rlongs.val.append(rlong(l))
        self.add(name, rlongs)
        return self

    def addString(self, name, stringValue):
        self.add(name, rstring(stringValue))
        return self

    def addTime(self, name, TimeValue):
        self.add(name, rtime(TimeValue))
        return self

_omero_sys.ParametersI = ParametersI
